@@ -1,17 +1,12 @@
-# standard Dash imports
 import dash
-from dash import dcc
-from dash import html
-
-# import for this example
-from pymatgen.ext.matproj import MPRester
+from dash import dcc, html
 from pymatgen.analysis.phase_diagram import PhaseDiagram
+from pymatgen.ext.matproj import MPRester
 
-# standard Crystal Toolkit import
 import crystal_toolkit.components as ctc
+from crystal_toolkit.settings import SETTINGS
 
-# create Dash app as normal
-app = dash.Dash()
+app = dash.Dash(assets_folder=SETTINGS.ASSETS_PATH)
 
 # If callbacks created dynamically they cannot be statically checked at app startup.
 # For this simple example this is not a problem, but if creating a complicated,
@@ -24,10 +19,10 @@ ctc.register_app(app)
 
 # first, retrieve entries from Materials Project
 with MPRester() as mpr:
-    # li_entries = mpr.get_entries_in_chemsys(["Li"])
-    # li_o_entries = mpr.get_entries_in_chemsys(["Li", "O"])
-    li_co_o_entries = mpr.get_entries_in_chemsys(["Li", "O", "Co"])
-    # li_co_o_fe_entries = mpr.get_entries_in_chemsys(["Li", "O", "Co", "Fe"])
+    # li_entries = mpr.get_entries_in_chemsys("Li")
+    # li_o_entries = mpr.get_entries_in_chemsys("Li-O")
+    li_co_o_entries = mpr.get_entries_in_chemsys("Li-O-Co")
+    # li_co_o_fe_entries = mpr.get_entries_in_chemsys("Li-O-Co-Fe")
 
 # and then create the phase diagrams
 # li_phase_diagram = PhaseDiagram(li_entries)
@@ -43,7 +38,6 @@ li_co_o_phase_diagram = PhaseDiagram(li_co_o_entries)
 li_co_o_phase_diagram_component = ctc.PhaseDiagramComponent(li_co_o_phase_diagram)
 # li_co_o_fe_phase_diagram_component = ctc.PhaseDiagramComponent(li_co_o_fe_phase_diagram)
 
-print(li_co_o_entries)
 
 # example layout to demonstrate capabilities of component
 my_layout = html.Div(
@@ -64,7 +58,7 @@ my_layout = html.Div(
 app.layout = ctc.crystal_toolkit_layout(my_layout)
 
 
-# allow app to be run using "python structure.py"
+# run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
 # see Dash documentation for more information
 if __name__ == "__main__":
