@@ -1,17 +1,12 @@
-# standard Dash imports
 import dash
-from dash import dcc
 from dash import html
-
-# import for this example
-from pymatgen.core.structure import Structure
 from pymatgen.core.lattice import Lattice
+from pymatgen.core.structure import Structure
 
-# standard Crystal Toolkit import
 import crystal_toolkit.components as ctc
+from crystal_toolkit.settings import SETTINGS
 
-# create Dash app as normal
-app = dash.Dash()
+app = dash.Dash(assets_folder=SETTINGS.ASSETS_PATH)
 
 # create the Structure object
 structure = Structure(
@@ -29,25 +24,19 @@ my_layout = html.Div(
     [
         html.H1("StructureMoleculeComponent Example"),
         html.H2("Standard Layout"),
-        structure_component.layout(size="400px"),
-        html.H2("Optional Additional Layouts"),
-        html.H3("Screenshot Layout"),
-        structure_component.screenshot_layout(),
-        html.H3("Options Layout"),
-        structure_component.options_layout(),
-        html.H3("Title Layout"),
+        structure_component.layout(),
+        html.H2("Optional Title Layout"),
         structure_component.title_layout(),
-        html.H3("Legend Layout"),
-        structure_component.legend_layout(),
-        html.H3("Download Layout"),
-        structure_component.download_layout(),
-    ]
+    ],
+    style=dict(
+        margin="2em auto", display="grid", placeContent="center", placeItems="center"
+    ),
 )
 
 # tell crystal toolkit about your app and layout
 ctc.register_crystal_toolkit(app, layout=my_layout)
 
-# allow app to be run using "python structure.py"
+# run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
 # see Dash documentation for more information
 if __name__ == "__main__":
