@@ -1,25 +1,19 @@
-# standard Dash imports
 import dash
 from dash import html
-from dash import dcc
-from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
-
-# standard Crystal Toolkit import
-import crystal_toolkit.components as ctc
+from dash.dependencies import Input, Output
 from dash_mp_components import JsonView
-
-# import for this example
-from pymatgen.core.structure import Structure
 from pymatgen.core.lattice import Lattice
+from pymatgen.core.structure import Structure
+from pymatgen.ext.matproj import MPRester
 
-# create Dash app as normal
-app = dash.Dash()
+import crystal_toolkit.components as ctc
+from crystal_toolkit.settings import SETTINGS
+
+app = dash.Dash(assets_folder=SETTINGS.ASSETS_PATH)
 
 # create the Structure object
 structure = Structure(Lattice.cubic(4.2), ["Na", "K"], [[0, 0, 0], [0.5, 0.5, 0.5]])
 
-from pymatgen.ext.matproj import MPRester
 
 # create an input structure as an example
 structure_component = ctc.StructureMoleculeComponent(
@@ -63,7 +57,10 @@ app.clientside_callback(
     }
     """,
     Output("json", "src"),
-    [Input(t.id(), "data") for t in transformation_component.transformations.values()],
+    [
+        Input(trafo.id(), "data")
+        for trafo in transformation_component.transformations.values()
+    ],
 )
 
 
@@ -75,7 +72,7 @@ def update_structure(struct):
     return struct
 
 
-# allow app to be run using "python structure.py"
+# run this app with "python path/to/this/file.py"
 # in production, deploy behind gunicorn or similar
 # see Dash documentation for more information
 if __name__ == "__main__":
