@@ -1,25 +1,39 @@
+from __future__ import annotations
+
 import logging
 import os
-from ast import literal_eval
+import warnings
 from random import choice
 from time import time
-from typing import Optional
+from typing import Any
 from urllib import parse
 from uuid import uuid4
 
 import dash
-import sentry_sdk
+from dash import dcc, html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 from flask_caching import Cache
 from monty.serialization import loadfn
+from pymatgen.core import Structure
 from pymatgen.core import __version__ as pmg_version
-from pymatgen.ext.matproj import MPRester
+from pymatgen.ext.matproj import MPRester, MPRestError
 
 import crystal_toolkit.components as ctc
 from crystal_toolkit import __file__ as module_path
 from crystal_toolkit.core.mpcomponent import MPComponent
-from crystal_toolkit.helpers.layouts import *
+from crystal_toolkit.core.panelcomponent import PanelComponent
+from crystal_toolkit.helpers.layouts import (
+    Box,
+    Column,
+    Columns,
+    Container,
+    Loading,
+    MessageBody,
+    MessageContainer,
+    MessageHeader,
+    Reveal,
+)
 from crystal_toolkit.settings import SETTINGS
 
 # choose a default structure on load
@@ -79,10 +93,6 @@ else:
 app.server.secret_key = str(uuid4())
 server = app.server
 
-# logging of errors
-if SETTINGS.SENTRY_DSN:
-    sentry_sdk.init(SETTINGS.SENTRY_DSN)
-
 # endregion
 ###########
 
@@ -144,7 +154,7 @@ xrd_panel = ctc.DiffractionPanelComponent(
     links={"default": transformation_component.id()}
 )
 # pbx_component = ctc.PourbaixDiagramPanelComponent(origin_component=struct_component)
-#
+
 symmetry_panel = ctc.SymmetryPanel(links={"default": struct_component.id()})
 localenv_panel = ctc.LocalEnvironmentPanel(
     links={
@@ -172,7 +182,7 @@ panels = [
 
 
 if SETTINGS.MP_EMBED_MODE:
-    mp_section = (html.Div(),)
+    mp_section: tuple[Any, ...] = (html.Div(),)
 else:
 
     # bsdos_component = ctc.BandstructureAndDosPanelComponent(
@@ -193,20 +203,20 @@ else:
     #     literature_component,
     # ]
 
-    mp_panels = []
+    mp_panels: list[PanelComponent] = []
 
     mp_section = (
-        H3("Materials Project"),
+        html.H3("Materials Project"),
         html.Div([panel.panel_layout() for panel in mp_panels], id="mp_panels"),
     )
 
 
 body_layout = [
     html.Br(),
-    H3("Transform"),
+    html.H3("Transform"),
     html.Div([transformation_component.layout()]),
     html.Br(),
-    H3("Analyze"),
+    html.H3("Analyze"),
     html.Div([panel.panel_layout() for panel in panels], id="panels"),
     # html.Br(),
     # *mp_section,
@@ -270,16 +280,20 @@ if api_offline:
 ################################################################################
 
 
-footer = Footer(
+footer = html.Footer(
     html.Div(
         [
             dcc.Markdown(
-                f"App created by [Crystal Toolkit Development Team](https://github.com/materialsproject/crystaltoolkit/graphs/contributors).  \n"
-                f"Bug reports and feature requests gratefully accepted, please send them to [@mkhorton](mailto:mkhorton@lbl.gov).  \n"
-                f"Powered by [The Materials Project](https://materialsproject.org), "
-                f"[pymatgen v{pmg_version}](http://pymatgen.org) and "
-                f"[Dash by Plotly](https://plot.ly/products/dash/). "
-                f"Deployed on [Spin](http://www.nersc.gov/users/data-analytics/spin/)."
+                f"""
+                App created by [Crystal Toolkit Development Team][contributors].\nBug reports and feature
+                requests gratefully accepted, please send them to [@mkhorton](mailto:mkhorton@lbl.gov).\n
+                Powered by [The Materials Project](https://materialsproject.org),
+                [pymatgen v{pmg_version}](http://pymatgen.org) and
+                [Dash by Plotly](https://plot.ly/products/dash/).
+                Deployed on [Spin](http://www.nersc.gov/users/data-analytics/spin/).
+
+                [contributors]: https://github.com/materialsproject/crystaltoolkit/graphs/contributors
+                """
             )
         ],
         className="content has-text-centered",
@@ -317,7 +331,7 @@ master_layout = Container(
     [
         dcc.Location(id="url", refresh=False),
         banner,
-        Section(
+        html.Section(
             [
                 Columns(
                     [
@@ -398,7 +412,7 @@ master_layout = Container(
                 Columns([Column(body_layout)]),
             ]
         ),
-        Section(footer),
+        html.Section(footer),
     ]
 )
 
@@ -414,9 +428,8 @@ ctc.register_crystal_toolkit(layout=master_layout, app=app, cache=cache)
 
 @app.callback(Output(search_component.id("input"), "value"), [Input("url", "href")])
 def update_search_term_on_page_load(href: str) -> str:
-    """
-    If an mpid is provided in the url, load that mpid. Otherwise
-    load a random mpid from the DEFAULT_MPIDS global variable.
+    """If an mpid is provided in the url, load that mpid. Otherwise load a random mpid from the
+    DEFAULT_MPIDS global variable.
 
     Args:
         href: e.g. "http://localhost:8050/mp-11358"
@@ -442,11 +455,12 @@ def update_search_term_on_page_load(href: str) -> str:
     [Input(search_component.id("input"), "value")],
     [State(search_component.id("input"), "n_submit")],
 )
-def perform_search_on_page_load(search_term: str, n_submit: Optional[int]):
-    """
-    Loading with an mpid in the URL requires populating the search term with
-    the mpid, this callback forces that search to then take place by force updating
-    n_submit and n_submit_timestamp props.
+def perform_search_on_page_load(
+    search_term: str, n_submit: int | None
+) -> tuple[int, int]:
+    """Loading with an mpid in the URL requires populating the search term with the mpid, this
+    callback forces that search to then take place by force updating n_submit and n_submit_timestamp
+    props.
 
     Args:
         search_term: e.g. mp-11358
@@ -462,10 +476,9 @@ def perform_search_on_page_load(search_term: str, n_submit: Optional[int]):
 
 
 @app.callback(Output("url", "pathname"), [Input(search_component.id(), "data")])
-def update_url_pathname_from_search_term(mpid: Optional[str]) -> str:
-    """
-    Updates the URL from the search term. Technically a circular callback,
-    this is done to prevent the app seeming inconsistent from the end user.
+def update_url_pathname_from_search_term(mpid: str | None) -> str:
+    """Updates the URL from the search term. Technically a circular callback, this is done to
+    prevent the app seeming inconsistent from the end user.
 
     Args:
         mpid: mpid
@@ -482,12 +495,12 @@ def update_url_pathname_from_search_term(mpid: Optional[str]) -> str:
     Output(transformation_component.id("input_structure"), "data"),
     [Input(search_component.id(), "data"), Input(upload_component.id(), "data")],
 )
-def master_update_structure(search_mpid: Optional[str], upload_data: Optional[str]):
-    """
-    A new structure is loaded either from the search component or from the
-    upload component. This callback triggers the update, and uses the callback
-    context to determine which should take precedence if there is both a search
-    term and uploaded data present.
+def master_update_structure(
+    search_mpid: str | None, upload_data: dict | None
+) -> Structure:
+    """A new structure is loaded either from the search component or from the upload component. This
+    callback triggers the update, and uses the callback context to determine which should take
+    precedence if there is both a search term and uploaded data present.
 
     Args:
         search_mpid: e.g. "mp-11358"
@@ -506,7 +519,7 @@ def master_update_structure(search_mpid: Optional[str], upload_data: Optional[st
         # triggered by both on initial load
         load_by = "mpid"
     elif (
-        dash.callback_context.triggered[0]["prop_id"] == search_component.id() + ".data"
+        dash.callback_context.triggered[0]["prop_id"] == f"{search_component.id()}.data"
     ):
         load_by = "mpid"
     else:
@@ -524,7 +537,7 @@ def master_update_structure(search_mpid: Optional[str], upload_data: Optional[st
             try:
                 struct = mpr.get_task_data(search_mpid, "structure")[0]["structure"]
                 print("Struct from task.")
-            except:
+            except MPRestError:
                 struct = mpr.get_structure_by_material_id(search_mpid)
                 print("Struct from material.")
     else:
