@@ -1,9 +1,10 @@
-from crystal_toolkit.apps.main import app
 import time
 
+from crystal_toolkit.apps.examples.tests.typing import DashDuo
+from crystal_toolkit.apps.main import app
 
-def test_main_app_startup(dash_duo):
 
+def test_main_app_startup(dash_duo: DashDuo):
     dash_duo.start_server(app)
     # dash_duo.clear_storage()
 
@@ -13,6 +14,5 @@ def test_main_app_startup(dash_duo):
     dash_duo.percy_snapshot("main_app_startup-layout")
     dash_duo.take_snapshot("main_app_startup-layout")
 
-    assert (
-        dash_duo.get_logs() == []
-    ), f"Browser console contains an error: {dash_duo.get_logs()}"
+    logs = dash_duo.get_logs()
+    assert logs == [], f"Unexpected browser {logs=}"
