@@ -1,16 +1,11 @@
 import itertools
 from multiprocessing import cpu_count
+from warnings import warn
 
-from dash import dcc
-from dash import html
-import plotly.express as px
-from dash import callback_context
+import dash_mp_components as mpc
+from dash import callback_context, dcc, html
 from dash.dependencies import Input, Output
 from dash.exceptions import PreventUpdate
-from dash_mp_components import GraphComponent
-from dscribe.descriptors import SOAP
-from dscribe.kernels import REMatchKernel
-from pymatgen.ext.matproj import MPRester
 from pymatgen.analysis.chemenv.coordination_environments.chemenv_strategies import (
     SimplestChemenvStrategy,
 )
@@ -23,40 +18,50 @@ from pymatgen.analysis.chemenv.coordination_environments.coordination_geometry_f
 from pymatgen.analysis.chemenv.coordination_environments.structure_environments import (
     LightStructureEnvironments,
 )
-from pymatgen.analysis.graphs import MoleculeGraph
-from pymatgen.analysis.graphs import StructureGraph
-from pymatgen.analysis.local_env import cn_opt_params, LocalStructOrderParams
+from pymatgen.analysis.graphs import MoleculeGraph, StructureGraph
+from pymatgen.analysis.local_env import LocalStructOrderParams, cn_opt_params
 from pymatgen.core.structure import Molecule, Structure
+from pymatgen.ext.matproj import MPRester
 from pymatgen.io.ase import AseAtomsAdaptor
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
-from pymatgen.util.string import unicodeify_species, unicodeify
+from pymatgen.util.string import unicodeify, unicodeify_species
 from sklearn.preprocessing import normalize
 
 from crystal_toolkit.components.structure import StructureMoleculeComponent
 from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.panelcomponent import PanelComponent
 from crystal_toolkit.helpers.layouts import (
-    get_data_list,
-    Columns,
-    Column,
-    get_tooltip,
-    cite_me,
-    Loading,
     H5,
+    Column,
+    Columns,
     Label,
+    Loading,
+    cite_me,
+    get_data_list,
+    get_tooltip,
 )
 
+try:
+    from dscribe.descriptors import SOAP
+    from dscribe.kernels import REMatchKernel
+except ImportError:
+    warn(
+        "Using dscribe SOAP and REMatchKernel requires the dscribe package "
+        "which was made optional since it in turn requires numba and numba "
+        "was a common source of installation issues."
+    )
+    SOAP = None
+
 
 def _get_local_order_parameters(structure_graph, n):
-    """
-    A copy of the method in pymatgen.analysis.local_env which
-    can operate on StructureGraph directly.
+    """A copy of the method in pymatgen.analysis.local_env which can operate on StructureGraph
+    directly.
 
     Calculate those local structure order parameters for
     the given site whose ideal CN corresponds to the
     underlying motif (e.g., CN=4, then calculate the
     square planar, tetrahedral, see-saw-like,
-    rectangular see-saw-like order paramters).
+    rectangular see-saw-like order parameters).
     Args:
         structure_graph: StructureGraph object
         n (int): site index.
@@ -69,8 +74,8 @@ def _get_local_order_parameters(structure_graph, n):
     # code from @nisse3000, moved here from graphs to avoid circular
     # import, also makes sense to have this as a general NN method
     cn = structure_graph.get_coordination_of_site(n)
-    if cn in [int(k_cn) for k_cn in cn_opt_params.keys()]:
-        names = [k for k in cn_opt_params[cn].keys()]
+    if cn in [int(k_cn) for k_cn in cn_opt_params]:
+        names = [k for k in cn_opt_params[cn]]
         types = []
         params = []
         for name in names:
@@ -243,7 +248,7 @@ class LocalEnvironmentPanel(PanelComponent):
                         html.Br(),
                         cite_me(
                             cite_text="How to cite ChemEnv",
-                            doi="10.26434/chemrxiv.11294480.v1",
+                            doi="10.1107/S2052520620007994",
                         ),
                         html.Br(),
                         distance_cutoff,
@@ -476,7 +481,7 @@ class LocalEnvironmentPanel(PanelComponent):
                 "data": [
                     {
                         "coloraxis": "coloraxis",
-                        #'hovertemplate': 'x: %{x}<br>y: %{y}<br>color: %{z}<extra></extra>',
+                        # 'hovertemplate': 'x: %{x}<br>y: %{y}<br>color: %{z}<extra></extra>',
                         "type": "heatmap",
                         "z": feature.tolist(),
                     }
@@ -531,6 +536,11 @@ class LocalEnvironmentPanel(PanelComponent):
             if not struct:
                 raise PreventUpdate
 
+            if not SOAP:
+                return mpc.Markdown(
+                    "This feature will not work unless `dscribe` is installed on the server."
+                )
+
             struct = self.from_data(struct)
             kwargs = self.reconstruct_kwargs_from_state(callback_context.inputs)
 
@@ -563,7 +573,7 @@ class LocalEnvironmentPanel(PanelComponent):
 
             with MPRester() as mpr:
                 docs = mpr.query(
-                    {"chemsys": {"$in": all_chemsyses}}, ["task_id", "structure"],
+                    {"chemsys": {"$in": all_chemsyses}}, ["task_id", "structure"]
                 )
             structs.update({d["task_id"]: d["structure"] for d in docs})
             return structs
@@ -577,6 +587,11 @@ class LocalEnvironmentPanel(PanelComponent):
             if not struct:
                 raise PreventUpdate
 
+            if not SOAP:
+                return mpc.Markdown(
+                    "This feature will not work unless `dscribe` is installed on the server."
+                )
+
             structs = {"input": self.from_data(struct)}
             kwargs = self.reconstruct_kwargs_from_state(callback_context.inputs)
 
@@ -629,7 +644,7 @@ class LocalEnvironmentPanel(PanelComponent):
                 if mpid != "input"
             }
 
-            sorted_mpids = sorted(similarities.keys(), key=lambda x: -similarities[x])
+            sorted_mpids = sorted(similarities, key=lambda x: -similarities[x])
 
             print("Generating similarity graphs")
             # TODO: was much slower using px.imshow (see prev commit)
@@ -706,7 +721,7 @@ class LocalEnvironmentPanel(PanelComponent):
             }
 
             return html.Div(
-                [GraphComponent(graph=graph_data, options=options)],
+                [mpc.GraphComponent(graph=graph_data, options=options)],
                 style={"width": "65vmin", "height": "65vmin"},
             )
 
