@@ -1,28 +1,17 @@
-import dash
-from dash import dcc
-from dash import html
-import plotly.graph_objs as go
-from dash.dependencies import Input, Output, State
-from dash.exceptions import PreventUpdate
+import re
 
 import numpy as np
-import re
-from matplotlib.cm import get_cmap
-
+import plotly.graph_objs as go
+from dash import dcc, html
+from dash.dependencies import Input, Output, State
+from dash.exceptions import PreventUpdate
+from pymatgen.analysis.pourbaix_diagram import ELEMENTS_HO, PREFAC, PourbaixDiagram
+from pymatgen.core import Composition
 from pymatgen.util.string import unicodeify
 from shapely.geometry import Polygon
-from pymatgen.core import Composition, Element
-from pymatgen.ext.matproj import MPRester
-from pymatgen.analysis.pourbaix_diagram import PourbaixDiagram, ELEMENTS_HO
 
-from crystal_toolkit.helpers.layouts import (
-    MessageContainer,
-    MessageBody,
-)
 import crystal_toolkit.helpers.layouts as ctl
 from crystal_toolkit.core.mpcomponent import MPComponent
-from crystal_toolkit.core.panelcomponent import PanelComponent
-
 
 __author__ = "Joseph Montoya"
 __email__ = "joseph.montoya@tri.global"
@@ -157,9 +146,9 @@ class PourbaixDiagramComponent(MPComponent):
     #             ph_mesh.ravel(), v_mesh.ravel(), decomposition_e.ravel()
     #         ):
     #             hovertext = [
-    #                 "∆G<sub>pbx</sub>={:.2f}".format(de_val),
-    #                 "ph={:.2f}".format(ph_val),
-    #                 "V={:.2f}".format(v_val),
+    #                 f"∆G<sub>pbx</sub>={de_val:.2f}",
+    #                 f"ph={ph_val:.2f}",
+    #                 f"V={v_val:.2f}",
     #             ]
     #             hovertext = "<br>".join(hovertext)
     #             hovertexts.append(hovertext)
@@ -234,7 +223,10 @@ class PourbaixDiagramComponent(MPComponent):
     #         if heatmap_entry is None:
     #             fillcolor = "White" if "Ion" in entry.phase_type else "PaleTurquoise"
     #             shape = go.layout.Shape(
-    #                 type="path", path=path, fillcolor=fillcolor, layer="below",
+    #                 type="path",
+    #                 path=path,
+    #                 fillcolor=fillcolor,
+    #                 layer="below",
     #             )
     #             shapes.append(shape)
     #
@@ -284,18 +276,17 @@ class PourbaixDiagramComponent(MPComponent):
 
     @staticmethod
     def get_figure(
-        pourbaix_diagram, heatmap_entry=None,
-    ):
-        """
-        Static method for getting plotly figure from a Pourbaix diagram.
+        pourbaix_diagram: PourbaixDiagram, heatmap_entry=None, show_water_lines=True
+    ) -> go.Figure:
+        """Static method for getting plotly figure from a Pourbaix diagram.
 
         Args:
             pourbaix_diagram (PourbaixDiagram): Pourbaix diagram to plot
             heatmap_entry (PourbaixEntry): id for the heatmap generation
+            show_water_lines (bool): if True, show region of water stability
 
         Returns:
             (dict) figure layout
-
         """
         data = []
 
@@ -327,10 +318,9 @@ class PourbaixDiagramComponent(MPComponent):
                 legend_entry = entry.phase_type
             elif isinstance(entry.phase_type, list):
                 if len(set(entry.phase_type)) == 1:
-                    if entry.phase_type[0] == "Ion":
-                        legend_entry = "Mixed Ion"
-                    else:
-                        legend_entry = "Mixed Solid"
+                    legend_entry = (
+                        "Mixed Ion" if entry.phase_type[0] == "Ion" else "Mixed Solid"
+                    )
                 else:
                     legend_entry = "Mixed Ion/Solid"
             else:
@@ -340,11 +330,11 @@ class PourbaixDiagramComponent(MPComponent):
 
             if not heatmap_entry:
                 if legend_entry == "Ion" or legend_entry == "Unknown":
-                    fillcolor = "rgb(255,255,250,1)"
+                    fillcolor = "rgb(255,255,250,1)"  # same color as old website
                 elif legend_entry == "Mixed Ion":
                     fillcolor = "rgb(255,255,240,1)"
                 elif legend_entry == "Solid":
-                    fillcolor = "rgba(188,236,237,1)"
+                    fillcolor = "rgba(188,236,237,1)"  # same color as old website
                 elif legend_entry == "Mixed Solid":
                     fillcolor = "rgba(155,229,232,1)"
                 elif legend_entry == "Mixed Ion/Solid":
@@ -389,7 +379,11 @@ class PourbaixDiagramComponent(MPComponent):
                 line = {"color": "Black", "width": 1}
 
             shape = go.layout.Shape(
-                type="path", path=path, fillcolor="rgba(0,0,0,0)", opacity=1, line=line,
+                type="path",
+                path=path,
+                fillcolor="rgba(0,0,0,0)",
+                opacity=1,
+                line=line,
             )
             shapes.append(shape)
 
@@ -425,9 +419,7 @@ class PourbaixDiagramComponent(MPComponent):
             #     return font_color
 
             def get_text_size(available_vertical_space):
-                """
-                Set text size based on available vertical space
-                """
+                """Set text size based on available vertical space."""
                 return min(max(6 * available_vertical_space, 12), 20)
 
             annotations = [
@@ -466,9 +458,9 @@ class PourbaixDiagramComponent(MPComponent):
                 ph_mesh.ravel(), v_mesh.ravel(), decomposition_e.ravel()
             ):
                 hovertext = [
-                    "∆G<sub>pbx</sub>={:.2f}".format(de_val),
-                    "ph={:.2f}".format(ph_val),
-                    "V={:.2f}".format(v_val),
+                    f"∆G<sub>pbx</sub>={de_val:.2f}",
+                    f"ph={ph_val:.2f}",
+                    f"V={v_val:.2f}",
                 ]
                 hovertext = "<br>".join(hovertext)
                 hovertexts.append(hovertext)
@@ -487,7 +479,10 @@ class PourbaixDiagramComponent(MPComponent):
                 z=decomposition_e,
                 x=list(ph_range),
                 y=list(v_range),
-                colorbar={"title": "∆G<sub>pbx</sub> (eV/atom)", "titleside": "right",},
+                colorbar={
+                    "title": "∆G<sub>pbx</sub> (eV/atom)",
+                    "titleside": "right",
+                },
                 colorscale=PourbaixDiagramComponent.colorscale,  # or magma
                 zmin=0,
                 zmax=1,
@@ -501,10 +496,35 @@ class PourbaixDiagramComponent(MPComponent):
             )
             data.append(hmap)
 
-        # SHE line
-        # data.append(go.Scatter(
-        #
-        # ))
+        if show_water_lines:
+            ph_range = [-2, 16]
+            # hydrogen line
+            data.append(
+                go.Scatter(
+                    x=[ph_range[0], ph_range[1]],
+                    y=[-ph_range[0] * PREFAC, -ph_range[1] * PREFAC],
+                    mode="lines",
+                    line={"color": "orange", "dash": "dash"},
+                    name="Hydrogen Stability Line",
+                )
+            )
+            # oxygen line
+            data.append(
+                go.Scatter(
+                    x=[ph_range[0], ph_range[1]],
+                    y=[-ph_range[0] * PREFAC + 1.23, -ph_range[1] * PREFAC + 1.23],
+                    mode="lines",
+                    line={"color": "orange", "dash": "dash"},
+                    name="Oxygen Stability Line",
+                )
+            )
+
+            #     h_line = np.transpose([[xlim[0], -xlim[0] * PREFAC], [xlim[1], -xlim[1] * PREFAC]])
+            #     o_line = np.transpose([[xlim[0], -xlim[0] * PREFAC + 1.23], [xlim[1], -xlim[1] * PREFAC + 1.23]])
+            # #   SHE line
+            # #   data.append(go.Scatter(
+            # #
+            # #   ))
 
         figure = go.Figure(data=data, layout=layout)
 
@@ -530,7 +550,7 @@ class PourbaixDiagramComponent(MPComponent):
                 self.get_bool_input(
                     "filter_solids",
                     state=self.default_state,
-                    label="Filter solids",
+                    label="Filter Solids",
                     help_str="Whether to filter solid phases by stability on the compositional phase diagram. "
                     "The practical consequence of this is that highly oxidized or reduced phases that "
                     "might show up in experiments due to kinetic limitations on oxygen/hydrogen evolution "
@@ -539,9 +559,9 @@ class PourbaixDiagramComponent(MPComponent):
                     "leads to the most accurate Pourbaix diagrams.",
                 ),
                 self.get_bool_input(
-                    "show_heatmap",
+                    "show_heatmap",  # kwarg_label
                     state=self.default_state,
-                    label="Show heatmap",
+                    label="Show Heatmap",
                     help_str="Hide or show a heatmap showing the decomposition energy for a specific "
                     "entry in this system.",
                 ),
@@ -553,24 +573,20 @@ class PourbaixDiagramComponent(MPComponent):
                             label="Heatmap entry",
                             help_str="Choose the entry to use for heatmap generation.",
                             disabled=True,
-                            style={"width": "20rem"},
                         )
                     ],
                     id=self.id("heatmap_choice_container"),
                 ),
                 html.Div(id=self.id("element_specific_controls")),
-            ],
-            style={"display": "inline-block"},
+            ]
         )
 
-        graph = ctl.Box(
-            ctl.Loading(
-                dcc.Graph(
-                    figure=go.Figure(layout=PourbaixDiagramComponent.empty_plot_style),
-                    id=self.id("graph"),
-                    responsive=True,
-                    config={"displayModeBar": False, "displaylogo": False},
-                )
+        graph = html.Div(
+            dcc.Graph(
+                figure=go.Figure(layout=PourbaixDiagramComponent.empty_plot_style),
+                id=self.id("graph"),
+                responsive=True,
+                config={"displayModeBar": False, "displaylogo": False},
             ),
             style={"min-height": "500px"},
         )
@@ -579,7 +595,10 @@ class PourbaixDiagramComponent(MPComponent):
 
     def layout(self):
         return html.Div(
-            children=[self._sub_layouts["options"], self._sub_layouts["graph"],]
+            children=[
+                self._sub_layouts["options"],
+                self._sub_layouts["graph"],
+            ]
         )
 
     def generate_callbacks(self, app, cache):
@@ -603,11 +622,10 @@ class PourbaixDiagramComponent(MPComponent):
             heatmap_options = self.get_choice_input(
                 "heatmap_choice",
                 state={},
-                label="Heatmap entry",
+                label="Heatmap Entry",
                 help_str="Choose the entry to use for heatmap generation.",
                 options=options,
                 disabled=False,
-                style={"width": "20rem"},
             )
 
             return heatmap_options
@@ -652,10 +670,8 @@ class PourbaixDiagramComponent(MPComponent):
                                 f"comp-{element}",
                                 default=comp_defaults[element],
                                 label=f"Composition of {element}",
-                                max=1,
-                                min=0,
+                                domain=[0, 1],
                                 step=0.01,
-                                disabled=True if heatmap_entry else False,
                             )
                         ]
                     )
@@ -674,13 +690,12 @@ class PourbaixDiagramComponent(MPComponent):
 
                 conc_inputs.append(conc_input)
 
-            comp_conc_controls = [html.Br()]
+            comp_conc_controls = []
             if comp_inputs and (not show_heatmap) and (not heatmap_entry):
-                comp_conc_controls.append(ctl.Label("Set Composition"))
                 comp_conc_controls += comp_inputs
-                comp_conc_controls.append(html.Br())
-                comp_conc_controls.append(html.Div(id=self.id("display-composition")))
-                comp_conc_controls.append(html.Br())
+                comp_conc_controls.append(
+                    ctl.Block(html.Div(id=self.id("display-composition")))
+                )
             if len(elements) > 1:
                 comp_conc_controls.append(ctl.Label("Set Ion Concentrations"))
             else:
@@ -714,9 +729,9 @@ class PourbaixDiagramComponent(MPComponent):
                 formula = Composition(
                     comp.get_integer_formula_and_factor()[0]
                 ).reduced_formula
-            except:
+            except Exception:
                 return html.Small(
-                    f"Invalid composition selected.", style={"color": "red"}
+                    "Invalid composition selected.", style={"color": "red"}
                 )
 
             return html.Small(f"Pourbaix composition set to {unicodeify(formula)}.")
@@ -727,25 +742,31 @@ class PourbaixDiagramComponent(MPComponent):
 
         @app.callback(
             Output(self.id("graph"), "figure"),
-            [Input(self.id(), "data"), Input(self.get_all_kwargs_id(), "value"),],
+            [
+                Input(self.id(), "data"),
+                Input(self.get_all_kwargs_id(), "value"),
+            ],
         )
-        def make_figure(pourbaix_entries, *args):
-
-            kwargs = self.reconstruct_kwargs_from_state()
+        def make_figure(pourbaix_entries, *args) -> go.Figure:
 
             if pourbaix_entries is None:
                 raise PreventUpdate
 
+            kwargs = self.reconstruct_kwargs_from_state()
+
             pourbaix_entries = self.from_data(pourbaix_entries)
 
             # Get heatmap id
             if kwargs["show_heatmap"] and kwargs.get("heatmap_choice"):
+
+                # get Entry object based on the heatmap_choice, which is entry_id string
                 heatmap_entry = next(
                     entry
                     for entry in pourbaix_entries
                     if entry.entry_id == kwargs["heatmap_choice"]
                 )
 
+                # if using heatmap, comp_dict is constrained and is set automatically
                 comp_dict = {
                     element: coeff
                     for element, coeff in heatmap_entry.composition.items()
@@ -754,7 +775,10 @@ class PourbaixDiagramComponent(MPComponent):
             else:
                 heatmap_entry = None
 
+                # otherwise, user sets comp_dict
                 comp_dict = {}
+                # e.g. kwargs contains {"comp-Ag": 0.5, "comp-Fe": 0.5},
+                # essentially {slider_name: slider_value}
                 for k, v in kwargs.items():
                     if "comp" in k:  # keys are encoded like "comp-Ag"
                         el = k.split("-")[1]
@@ -762,22 +786,35 @@ class PourbaixDiagramComponent(MPComponent):
                 comp_dict = comp_dict or None
 
             conc_dict = {}
+            # e.g. kwargs contains {"conc-Ag": 1e-6, "conc-Fe": 1e-4},
+            # essentially {slider_name: slider_value}
             for k, v in kwargs.items():
                 if "conc" in k:  # keys are encoded like "conc-Ag"
                     el = k.split("-")[1]
                     conc_dict[el] = v
             conc_dict = conc_dict or None
 
-            # print("requesting pourbaix diagram", len(pourbaix_entries), heatmap_entry, conc_dict, comp_dict)
-
             pourbaix_diagram = get_pourbaix_diagram(
                 pourbaix_entries,
                 comp_dict=comp_dict,
                 conc_dict=conc_dict,
                 filter_solids=kwargs["filter_solids"],
             )
-            self.logger.debug("Generated pourbaix diagram")
+            self.logger.debug(
+                "Generated pourbaix diagram",
+                len(pourbaix_entries),
+                heatmap_entry,
+                conc_dict,
+                comp_dict,
+            )
 
-            fig = self.get_figure(pourbaix_diagram, heatmap_entry=heatmap_entry,)
+            fig = self.get_figure(
+                pourbaix_diagram,
+                heatmap_entry=heatmap_entry,
+            )
 
             return fig
+
+    # TODO
+    # def graph_layout(self):
+    #     return self._sub_layouts["graph"]
