@@ -1,47 +1,37 @@
-from pathlib import Path
+from __future__ import annotations
 
-from tempfile import TemporaryDirectory
-
-from base64 import b64encode
-
-import json
-import os
 import re
-import sys
 import warnings
+from base64 import b64encode
 from collections import OrderedDict
 from itertools import chain, combinations_with_replacement
-from pymatgen.io.vasp.sets import MPRelaxSet
-from typing import Dict, Optional, Tuple, Union
+from pathlib import Path
+from tempfile import TemporaryDirectory
+from typing import Literal
 
-import dash
-from dash import dash_table as dt
 import numpy as np
-from dash.dependencies import Input, Output, State, MATCH
+from dash import dash_table as dt
+from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 from dash_mp_components import CrystalToolkitScene
+from emmet.core.settings import EmmetSettings
 from pymatgen.analysis.graphs import MoleculeGraph, StructureGraph
 from pymatgen.analysis.local_env import NearNeighbors
 from pymatgen.core.composition import Composition
 from pymatgen.core.periodic_table import DummySpecie
 from pymatgen.core.structure import Molecule, Structure
+from pymatgen.io.vasp.sets import MPRelaxSet
 from pymatgen.symmetry.analyzer import SpacegroupAnalyzer
-from emmet.core.settings import EmmetSettings
 
 from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.mpcomponent import MPComponent
 from crystal_toolkit.core.scene import Scene
-from crystal_toolkit.helpers.layouts import *
+from crystal_toolkit.helpers.layouts import H2, Field, dcc, html
 from crystal_toolkit.settings import SETTINGS
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
-
 # TODO: make dangling bonds "stubs"? (fixed length)
 
-DEFAULTS = {
+DEFAULTS: dict[str, str | bool] = {
     "color_scheme": "VESTA",
     "bonding_strategy": "CrystalNN",
     "radius_strategy": "uniform",
@@ -50,13 +40,19 @@ DEFAULTS = {
     "hide_incomplete_bonds": True,
     "show_compass": True,
     "unit_cell_choice": "input",
+    "show_legend": True,
+    "show_settings": True,
+    "show_controls": True,
+    "show_expand_button": True,
+    "show_image_button": True,
+    "show_export_button": True,
+    "show_position_button": True,
 }
 
 
 class StructureMoleculeComponent(MPComponent):
-    """
-    A component to display pymatgen Structure, Molecule, StructureGraph
-    and MoleculeGraph objects.
+    """A component to display pymatgen Structure, Molecule, StructureGraph and MoleculeGraph
+    objects.
     """
 
     available_bonding_strategies = {
@@ -90,15 +86,15 @@ class StructureMoleculeComponent(MPComponent):
 
     def __init__(
         self,
-        struct_or_mol: Optional[
-            Union[Structure, StructureGraph, Molecule, MoleculeGraph]
-        ] = None,
+        struct_or_mol: None
+        | (Structure | StructureGraph | Molecule | MoleculeGraph) = None,
         id: str = None,
-        scene_additions: Optional[Scene] = None,
+        className: str = "box",
+        scene_additions: Scene | None = None,
         bonding_strategy: str = DEFAULTS["bonding_strategy"],
-        bonding_strategy_kwargs: Optional[dict] = None,
+        bonding_strategy_kwargs: dict | None = None,
         color_scheme: str = DEFAULTS["color_scheme"],
-        color_scale: Optional[str] = None,
+        color_scale: str | None = None,
         radius_strategy: str = DEFAULTS["radius_strategy"],
         unit_cell_choice: str = DEFAULTS["unit_cell_choice"],
         draw_image_atoms: bool = DEFAULTS["draw_image_atoms"],
@@ -107,32 +103,60 @@ class StructureMoleculeComponent(MPComponent):
         ],
         hide_incomplete_bonds: bool = DEFAULTS["hide_incomplete_bonds"],
         show_compass: bool = DEFAULTS["show_compass"],
-        scene_settings: Optional[Dict] = None,
-        group_by_site_property: Optional[str] = None,
+        scene_settings: dict | None = None,
+        group_by_site_property: str | None = None,
+        show_legend: bool = DEFAULTS["show_legend"],
+        show_settings: bool = DEFAULTS["show_settings"],
+        show_controls: bool = DEFAULTS["show_controls"],
+        show_expand_button: bool = DEFAULTS["show_expand_button"],
+        show_image_button: bool = DEFAULTS["show_image_button"],
+        show_export_button: bool = DEFAULTS["show_export_button"],
+        show_position_button: bool = DEFAULTS["show_position_button"],
         **kwargs,
     ):
-        """
-        Create a StructureMoleculeComponent from a structure or molecule.
+        """Create a StructureMoleculeComponent from a structure or molecule.
 
-        :param struct_or_mol: input structure or molecule
-        :param id: canonical id
-        :param scene_additions: extra geometric elements to add to the 3D scene
-        :param bonding_strategy: bonding strategy from pymatgen NearNeighbors class
-        :param bonding_strategy_kwargs: options for the bonding strategy
-        :param color_scheme: color scheme, see Legend class
-        :param color_scale: color scale, see Legend class
-        :param radius_strategy: radius strategy, see Legend class
-        :param draw_image_atoms: whether to draw repeats of atoms on periodic images
-        :param bonded_sites_outside_unit_cell: whether to draw sites bonded outside the unit cell
-        :param hide_incomplete_bonds: whether to hide or show incomplete bonds
-        :param show_compass: whether to hide or show the compass
-        :param scene_settings: scene settings (lighting etc.) to pass to CrystalToolkitScene
-        :param group_by_site_property: a site property used for grouping of atoms for mouseover/interaction,
-        e.g. Wyckoff label
-        :param kwargs: extra keyword arguments to pass to MPComponent
+        Args:
+            struct_or_mol (None |, optional): input structure or molecule. Defaults to None.
+            id (str, optional): canonical id. Defaults to None.
+            className (str, optional): extra geometric elements to add to the 3D scene. Defaults to "box".
+            scene_additions (Scene | None, optional): bonding strategy from pymatgen NearNeighbors class.
+                Defaults to None.
+            bonding_strategy (str, optional): options for the bonding strategy.
+            bonding_strategy_kwargs (dict | None, optional): color scheme, see Legend class.
+                Defaults to None.
+            color_scheme (str, optional): color scale, see Legend class.
+            color_scale (str | None, optional): radius strategy, see Legend class.
+                Defaults to None.
+            radius_strategy (str, optional):  optional): radius strategy, see Legend class.
+            unit_cell_choice (str, optional): whether to draw repeats of atoms on periodic images.
+            draw_image_atoms (bool, optional): whether to draw sites bonded outside the unit cell.
+            bonded_sites_outside_unit_cell (bool, optional): whether to hide or show incomplete bonds.
+                Defaults to DEFAULTS[ "bonded_sites_outside_unit_cell" ].
+            hide_incomplete_bonds (bool, optional): whether to hide or show the compass.
+            show_compass (bool, optional): scene settings (lighting etc.) to pass to CrystalToolkitScene.
+            scene_settings (dict | None, optional): a site property used for grouping of atoms for
+                mouseover/interaction. Defaults to None.
+            group_by_site_property (str | None, optional): a site property used for grouping of atoms for
+                mouseover/interaction. Defaults to None.
+            show_legend (bool, optional):  optional): show or hide legend panel within the scene.
+            show_settings (bool, optional): show or hide scene control bar.
+            show_controls (bool, optional): show or hide the full screen button within the scene control bar.
+            show_expand_button (bool, optional): show or hide the image download button within the scene control bar.
+            show_image_button (bool, optional): show or hide the file export button within the scene control bar.
+            show_export_button (bool, optional): show or hide the revert position button within the scene control bar.
+            show_position_button (bool, optional): extra keyword arguments to pass to MPComponent. e.g. Wyckoff label.
+            **kwargs: a CSS dimension specifying width/height of Div.
         """
-
         super().__init__(id=id, default_data=struct_or_mol, **kwargs)
+        self.className = className
+        self.show_legend = show_legend
+        self.show_settings = show_settings
+        self.show_controls = show_controls
+        self.show_expand_button = show_expand_button
+        self.show_image_button = show_image_button
+        self.show_export_button = show_export_button
+        self.show_position_button = show_position_button
 
         self.initial_scene_settings = self.default_scene_settings.copy()
         if scene_settings:
@@ -227,7 +251,7 @@ class StructureMoleculeComponent(MPComponent):
         app.clientside_callback(
             """
             function (bonding_strategy, custom_cutoffs_rows, unit_cell_choice) {
-            
+
                 const bonding_strategy_kwargs = {}
                 if (bonding_strategy === 'CutOffDictNN') {
                     const cut_off_dict = []
@@ -236,7 +260,7 @@ class StructureMoleculeComponent(MPComponent):
                     })
                     bonding_strategy_kwargs.cut_off_dict = cut_off_dict
                 }
-            
+
                 return {
                     bonding_strategy: bonding_strategy,
                     bonding_strategy_kwargs: bonding_strategy_kwargs,
@@ -270,12 +294,14 @@ class StructureMoleculeComponent(MPComponent):
         app.clientside_callback(
             """
             function (colorScheme, radiusStrategy, drawOptions, displayOptions) {
-            
-                const newDisplayOptions = Object.assign({}, displayOptions);
+
+                const newDisplayOptions = {...displayOptions}
                 newDisplayOptions.color_scheme = colorScheme
                 newDisplayOptions.radius_strategy = radiusStrategy
                 newDisplayOptions.draw_image_atoms = drawOptions.includes('draw_image_atoms')
-                newDisplayOptions.bonded_sites_outside_unit_cell =  drawOptions.includes('bonded_sites_outside_unit_cell')
+                newDisplayOptions.bonded_sites_outside_unit_cell = drawOptions.includes(
+                    'bonded_sites_outside_unit_cell'
+                )
                 newDisplayOptions.hide_incomplete_bonds = drawOptions.includes('hide_incomplete_bonds')
 
                 return newDisplayOptions
@@ -411,14 +437,18 @@ class StructureMoleculeComponent(MPComponent):
         # )
 
         @app.callback(
-            Output(self.id("scene"), "imageRequest"),
-            [Input(self.id("screenshot_button"), "n_clicks")],
-            [State(self.id("scene"), "imageRequest"), State(self.id(), "data")],
+            Output(self.id("download-image"), "data"),
+            Input(self.id("scene"), "imageDataTimestamp"),
+            [
+                State(self.id("scene"), "imageData"),
+                State(self.id(), "data"),
+            ],
         )
-        def trigger_screenshot(n_clicks, current_requests, struct_or_mol):
-            if n_clicks is None:
+        def download_image(image_data_timestamp, image_data, data):
+            if not image_data_timestamp:
                 raise PreventUpdate
-            struct_or_mol = self.from_data(struct_or_mol)
+
+            struct_or_mol = self.from_data(data)
             if isinstance(struct_or_mol, StructureGraph):
                 formula = struct_or_mol.structure.composition.reduced_formula
             elif isinstance(struct_or_mol, MoleculeGraph):
@@ -429,47 +459,25 @@ class StructureMoleculeComponent(MPComponent):
                 spgrp = struct_or_mol.get_space_group_info()[0]
             else:
                 spgrp = ""
-            request_filename = "{}-{}-crystal-toolkit.png".format(formula, spgrp)
-            if not current_requests:
-                n_requests = 1
-            else:
-                n_requests = current_requests["n_requests"] + 1
-            return {
-                "n_requests": n_requests,
-                "filename": request_filename,
-                "filetype": "png",
-            }
-
-        @app.callback(
-            Output(self.id("download"), "data"),
-            Input(self.id("scene"), "imageDataTimestamp"),
-            [
-                State(self.id("scene"), "imageData"),
-                State(self.id("scene"), "imageRequest"),
-            ],
-        )
-        def download_image(image_data_timestamp, image_data, image_request):
-            if not image_data_timestamp:
-                raise PreventUpdate
+            request_filename = f"{formula}-{spgrp}-crystal-toolkit.png"
 
             return {
                 "content": image_data[len("data:image/png;base64,") :],
-                "filename": image_request["filename"],
+                "filename": request_filename,
                 "base64": True,
                 "type": "image/png",
             }
 
         @app.callback(
             Output(self.id("download-structure"), "data"),
-            Input(self.id("download-button"), "n_clicks"),
+            Input(self.id("scene"), "fileTimestamp"),
             [
-                State(self.get_kwarg_id("download_option"), "value"),
+                State(self.id("scene"), "fileType"),
                 State(self.id(), "data"),
             ],
         )
-        def download_structure(n_clicks, download_option, data):
-
-            if not n_clicks:
+        def download_structure(file_timestamp, download_option, data):
+            if not file_timestamp:
                 raise PreventUpdate
 
             structure = self.from_data(data)
@@ -478,8 +486,6 @@ class StructureMoleculeComponent(MPComponent):
 
             file_prefix = structure.composition.reduced_formula
 
-            download_option = download_option[0]
-
             if "VASP" not in download_option:
 
                 extension = self.download_options["Structure"][download_option]["fmt"]
@@ -596,8 +602,8 @@ class StructureMoleculeComponent(MPComponent):
 
         try:
             formula = Composition.from_dict(legend["composition"]).reduced_formula
-        except:
-            # TODO: fix legend for Dummy Specie compositions
+        except Exception:
+            # TODO: fix legend for DummySpecies compositions
             formula = "Unknown"
 
         legend_colors = OrderedDict(
@@ -605,20 +611,21 @@ class StructureMoleculeComponent(MPComponent):
         )
 
         legend_elements = [
-            Button(
+            html.Span(
                 html.Span(
                     name, className="icon", style={"color": get_font_color(color)}
                 ),
-                kind="static",
+                className="button is-static is-rounded",
                 style={"backgroundColor": color},
             )
             for color, name in legend_colors.items()
         ]
 
-        return Field(
-            [Control(el, style={"marginRight": "0.2rem"}) for el in legend_elements],
+        return html.Div(
+            legend_elements,
             id=self.id("legend"),
-            grouped=True,
+            style={"display": "flex"},
+            className="buttons",
         )
 
     def _make_title(self, legend):
@@ -649,8 +656,8 @@ class StructureMoleculeComponent(MPComponent):
                     else html.Span(part.strip())
                     for part in formula_parts
                 ]
-            except:
-                formula_components = list(map(str, composition.keys()))
+            except Exception:
+                formula_components = list(map(str, composition))
 
         return H2(
             formula_components, id=self.id("title"), style={"display": "inline-block"}
@@ -665,9 +672,7 @@ class StructureMoleculeComponent(MPComponent):
         species = set(
             map(
                 str,
-                chain.from_iterable(
-                    [list(c.keys()) for c in struct_or_mol.species_and_occu]
-                ),
+                chain.from_iterable([list(c) for c in struct_or_mol.species_and_occu]),
             )
         )
         rows = [
@@ -679,47 +684,11 @@ class StructureMoleculeComponent(MPComponent):
     @property
     def _sub_layouts(self):
 
-        struct_layout = html.Div(
-            [
-                CrystalToolkitScene(
-                    id=self.id("scene"),
-                    data=self.initial_data["scene"],
-                    settings=self.initial_scene_settings,
-                    sceneSize="100%",
-                    **self.scene_kwargs,
-                ),
-            ],
-            style={
-                "width": "100%",
-                "height": "100%",
-                "overflow": "hidden",
-                "margin": "0 auto",
-            },
-        )
-
-        screenshot_layout = html.Div(
-            [
-                Button(
-                    [Icon(kind="download"), html.Span(), "Download Image"],
-                    kind="primary",
-                    id=self.id("screenshot_button"),
-                ),
-                dcc.Download(id=self.id("download")),
-            ],
-            # TODO: change to "bottom" when dropdown included
-            style={"verticalAlign": "top", "display": "inline-block"},
-        )
-
         title_layout = html.Div(
             self._make_title(self._initial_data["legend_data"]),
             id=self.id("title_container"),
         )
 
-        legend_layout = html.Div(
-            self._make_legend(self._initial_data["legend_data"]),
-            id=self.id("legend_container"),
-        )
-
         nn_mapping = {
             "CrystalNN": "CrystalNN",
             "Custom Bonds": "CutOffDictNN",
@@ -760,178 +729,188 @@ class StructureMoleculeComponent(MPComponent):
             style={"display": "none"},
         )
 
-        options_layout = Field(
-            [
-                #  TODO: hide if molecule
-                html.Label("Change unit cell:", className="mpc-label"),
-                html.Div(
-                    dcc.Dropdown(
-                        options=[
-                            {"label": "Input cell", "value": "input"},
-                            {"label": "Primitive cell", "value": "primitive"},
-                            {"label": "Conventional cell", "value": "conventional"},
-                            {
-                                "label": "Reduced cell (Niggli)",
-                                "value": "reduced_niggli",
-                            },
-                            {"label": "Reduced cell (LLL)", "value": "reduced_lll"},
-                        ],
-                        value="input",
-                        clearable=False,
-                        id=self.id("unit-cell-choice"),
-                        persistence=SETTINGS.PERSISTENCE,
-                        persistence_type=SETTINGS.PERSISTENCE_TYPE,
-                    ),
-                    className="mpc-control",
-                ),
-                html.Div(
-                    [
-                        html.Label("Change bonding algorithm: ", className="mpc-label"),
-                        bonding_algorithm,
-                        bonding_algorithm_custom_cutoffs,
-                    ]
-                ),
-                html.Label("Change color scheme:", className="mpc-label"),
-                html.Div(
-                    dcc.Dropdown(
-                        options=[
-                            {"label": "VESTA", "value": "VESTA"},
-                            {"label": "Jmol", "value": "Jmol"},
-                            {"label": "Accessible", "value": "accessible"},
-                        ],
-                        value=self.initial_data["display_options"]["color_scheme"],
-                        clearable=False,
-                        persistence=SETTINGS.PERSISTENCE,
-                        persistence_type=SETTINGS.PERSISTENCE_TYPE,
-                        id=self.id("color-scheme"),
-                    ),
-                    className="mpc-control",
-                ),
-                html.Label("Change atomic radii:", className="mpc-label"),
-                html.Div(
-                    dcc.Dropdown(
-                        options=[
-                            {"label": "Ionic", "value": "specified_or_average_ionic"},
-                            {"label": "Covalent", "value": "covalent"},
-                            {"label": "Van der Waals", "value": "van_der_waals"},
-                            {
-                                "label": f"Uniform ({Legend.uniform_radius}Å)",
-                                "value": "uniform",
-                            },
-                        ],
-                        value=self.initial_data["display_options"]["radius_strategy"],
-                        clearable=False,
-                        persistence=SETTINGS.PERSISTENCE,
-                        persistence_type=SETTINGS.PERSISTENCE_TYPE,
-                        id=self.id("radius_strategy"),
-                    ),
-                    className="mpc-control",
-                ),
-                html.Label("Draw options:", className="mpc-label"),
-                html.Div(
-                    [
-                        dcc.Checklist(
+        if self.show_settings:
+            options_layout = Field(
+                [
+                    #  TODO: hide if molecule
+                    html.Label("Change unit cell:", className="mpc-label"),
+                    html.Div(
+                        dcc.Dropdown(
                             options=[
+                                {"label": "Input cell", "value": "input"},
+                                {"label": "Primitive cell", "value": "primitive"},
+                                {"label": "Conventional cell", "value": "conventional"},
                                 {
-                                    "label": "Draw repeats of atoms on periodic boundaries",
-                                    "value": "draw_image_atoms",
-                                },
-                                {
-                                    "label": "Draw atoms outside unit cell bonded to "
-                                    "atoms within unit cell",
-                                    "value": "bonded_sites_outside_unit_cell",
-                                },
-                                {
-                                    "label": "Hide bonds where destination atoms are not shown",
-                                    "value": "hide_incomplete_bonds",
+                                    "label": "Reduced cell (Niggli)",
+                                    "value": "reduced_niggli",
                                 },
+                                {"label": "Reduced cell (LLL)", "value": "reduced_lll"},
                             ],
-                            value=[
-                                opt
-                                for opt in (
-                                    "draw_image_atoms",
-                                    "bonded_sites_outside_unit_cell",
-                                    "hide_incomplete_bonds",
-                                )
-                                if self.initial_data["display_options"][opt]
-                            ],
-                            labelStyle={"display": "block"},
-                            inputClassName="mpc-radio",
-                            id=self.id("draw_options"),
+                            value="input",
+                            clearable=False,
+                            id=self.id("unit-cell-choice"),
                             persistence=SETTINGS.PERSISTENCE,
                             persistence_type=SETTINGS.PERSISTENCE_TYPE,
-                        )
-                    ]
-                ),
-                html.Label("Hide/show:", className="mpc-label"),
-                html.Div(
-                    [
-                        dcc.Checklist(
+                        ),
+                        className="mpc-control",
+                    ),
+                    html.Div(
+                        [
+                            html.Label(
+                                "Change bonding algorithm: ", className="mpc-label"
+                            ),
+                            bonding_algorithm,
+                            bonding_algorithm_custom_cutoffs,
+                        ]
+                    ),
+                    html.Label("Change color scheme:", className="mpc-label"),
+                    html.Div(
+                        dcc.Dropdown(
                             options=[
-                                {"label": "Atoms", "value": "atoms"},
-                                {"label": "Bonds", "value": "bonds"},
-                                {"label": "Unit cell", "value": "unit_cell"},
-                                {"label": "Polyhedra", "value": "polyhedra"},
-                                {"label": "Axes", "value": "axes"},
+                                {"label": "VESTA", "value": "VESTA"},
+                                {"label": "Jmol", "value": "Jmol"},
+                                {"label": "Accessible", "value": "accessible"},
                             ],
-                            value=["atoms", "bonds", "unit_cell", "polyhedra"],
-                            labelStyle={"display": "block"},
-                            inputClassName="mpc-radio",
-                            id=self.id("hide-show"),
+                            value=self.initial_data["display_options"]["color_scheme"],
+                            clearable=False,
                             persistence=SETTINGS.PERSISTENCE,
                             persistence_type=SETTINGS.PERSISTENCE_TYPE,
-                        )
-                    ],
-                    className="mpc-control",
-                ),
-            ]
-        )
+                            id=self.id("color-scheme"),
+                        ),
+                        className="mpc-control",
+                    ),
+                    html.Label("Change atomic radii:", className="mpc-label"),
+                    html.Div(
+                        dcc.Dropdown(
+                            options=[
+                                {
+                                    "label": "Ionic",
+                                    "value": "specified_or_average_ionic",
+                                },
+                                {"label": "Covalent", "value": "covalent"},
+                                {"label": "Van der Waals", "value": "van_der_waals"},
+                                {
+                                    "label": f"Uniform ({Legend.uniform_radius}Å)",
+                                    "value": "uniform",
+                                },
+                            ],
+                            value=self.initial_data["display_options"][
+                                "radius_strategy"
+                            ],
+                            clearable=False,
+                            persistence=SETTINGS.PERSISTENCE,
+                            persistence_type=SETTINGS.PERSISTENCE_TYPE,
+                            id=self.id("radius_strategy"),
+                        ),
+                        className="mpc-control",
+                    ),
+                    html.Label("Draw options:", className="mpc-label"),
+                    html.Div(
+                        [
+                            dcc.Checklist(
+                                options=[
+                                    {
+                                        "label": "Draw repeats of atoms on periodic boundaries",
+                                        "value": "draw_image_atoms",
+                                    },
+                                    {
+                                        "label": "Draw atoms outside unit cell bonded to "
+                                        "atoms within unit cell",
+                                        "value": "bonded_sites_outside_unit_cell",
+                                    },
+                                    {
+                                        "label": "Hide bonds where destination atoms are not shown",
+                                        "value": "hide_incomplete_bonds",
+                                    },
+                                ],
+                                value=[
+                                    opt
+                                    for opt in (
+                                        "draw_image_atoms",
+                                        "bonded_sites_outside_unit_cell",
+                                        "hide_incomplete_bonds",
+                                    )
+                                    if self.initial_data["display_options"][opt]
+                                ],
+                                labelStyle={"display": "block"},
+                                inputClassName="mpc-radio",
+                                id=self.id("draw_options"),
+                                persistence=SETTINGS.PERSISTENCE,
+                                persistence_type=SETTINGS.PERSISTENCE_TYPE,
+                            )
+                        ]
+                    ),
+                    html.Label("Hide/show:", className="mpc-label"),
+                    html.Div(
+                        [
+                            dcc.Checklist(
+                                options=[
+                                    {"label": "Atoms", "value": "atoms"},
+                                    {"label": "Bonds", "value": "bonds"},
+                                    {"label": "Unit cell", "value": "unit_cell"},
+                                    {"label": "Polyhedra", "value": "polyhedra"},
+                                    {"label": "Axes", "value": "axes"},
+                                ],
+                                value=["atoms", "bonds", "unit_cell", "polyhedra"],
+                                labelStyle={"display": "block"},
+                                inputClassName="mpc-radio",
+                                id=self.id("hide-show"),
+                                persistence=SETTINGS.PERSISTENCE,
+                                persistence_type=SETTINGS.PERSISTENCE_TYPE,
+                            )
+                        ],
+                        className="mpc-control",
+                    ),
+                ]
+            )
+        else:
+            options_layout = None
 
-        state = {"fmt": "CIF (Symmetrized)"}
+        if self.show_legend:
+            legend_layout = html.Div(
+                self._make_legend(self._initial_data["legend_data"]),
+                id=self.id("legend_container"),
+            )
+        else:
+            legend_layout = None
 
-        download_options = self.get_choice_input(
-            kwarg_label="download_option",
-            state=state,
-            options=[
-                {"label": k, "value": k}
-                for k, v in self.download_options["Structure"].items()
-            ],
-            style={
-                "border-radius": "4px 0px 0px 4px",
-                "width": "12rem",
-                "height": "1.5rem",
-            },
-        )
-
-        download_button = Button(
-            [Icon(kind="download"), html.Span(), "Download"],
-            kind="primary",
-            id=self.id("download-button"),
-            style={"height": "2.25rem"},
-        )
-
-        download_layout = html.Div(
+        struct_layout = html.Div(
             [
-                html.Div([download_options], className="control"),
-                html.Div([download_button], className="control"),
+                CrystalToolkitScene(
+                    [options_layout, legend_layout],
+                    id=self.id("scene"),
+                    className=self.className,
+                    data=self.initial_data["scene"],
+                    settings=self.initial_scene_settings,
+                    sceneSize="100%",
+                    fileOptions=list(self.download_options["Structure"]),
+                    showControls=self.show_controls,
+                    showExpandButton=self.show_expand_button,
+                    showImageButton=self.show_image_button,
+                    showExportButton=self.show_export_button,
+                    showPositionButton=self.show_position_button,
+                    **self.scene_kwargs,
+                ),
+                dcc.Download(id=self.id("download-image")),
                 dcc.Download(id=self.id("download-structure")),
-            ],
-            className="field has-addons",
+            ]
         )
 
         return {
             "struct": struct_layout,
-            "screenshot": screenshot_layout,
             "options": options_layout,
             "title": title_layout,
             "legend": legend_layout,
-            "download": download_layout,
         }
 
     def layout(self, size: str = "500px") -> html.Div:
-        """
-        :param size: a CSS string specifying width/height of Div
-        :return: A html.Div containing the 3D structure or molecule
+        """Get the layout for this component.
+
+        Args:
+            size (str, optional): a CSS dimension specifying width/height of Div. Defaults to "500px".
+
+        Returns:
+            html.Div: A html.Div containing the 3D structure or molecule
         """
         return html.Div(
             self._sub_layouts["struct"], style={"width": size, "height": size}
@@ -939,7 +918,7 @@ class StructureMoleculeComponent(MPComponent):
 
     @staticmethod
     def _preprocess_structure(
-        struct_or_mol: Union[Structure, StructureGraph, Molecule, MoleculeGraph],
+        struct_or_mol: Structure | StructureGraph | Molecule | MoleculeGraph,
         unit_cell_choice: Literal[
             "input", "primitive", "conventional", "reduced_niggli", "reduced_lll"
         ] = "input",
@@ -963,14 +942,14 @@ class StructureMoleculeComponent(MPComponent):
 
     @staticmethod
     def _preprocess_input_to_graph(
-        input: Union[Structure, StructureGraph, Molecule, MoleculeGraph],
+        input: Structure | StructureGraph | Molecule | MoleculeGraph,
         bonding_strategy: str = DEFAULTS["bonding_strategy"],
-        bonding_strategy_kwargs: Optional[Dict] = None,
-    ) -> Union[StructureGraph, MoleculeGraph]:
+        bonding_strategy_kwargs: dict | None = None,
+    ) -> StructureGraph | MoleculeGraph:
 
         if isinstance(input, Structure):
 
-            # ensure fractional co-ordinates are normalized to be in [0,1)
+            # ensure fractional coordinates are normalized to be in [0,1)
             # (this is actually not guaranteed by Structure)
             try:
                 input = input.as_dict(verbosity=0)
@@ -993,15 +972,14 @@ class StructureMoleculeComponent(MPComponent):
         else:
             if (
                 bonding_strategy
-                not in StructureMoleculeComponent.available_bonding_strategies.keys()
+                not in StructureMoleculeComponent.available_bonding_strategies
             ):
+                valid_subclasses = ", ".join(
+                    StructureMoleculeComponent.available_bonding_strategies
+                )
                 raise ValueError(
-                    "Bonding strategy not supported. Please supply a name "
-                    "of a NearNeighbor subclass, choose from: {}".format(
-                        ", ".join(
-                            StructureMoleculeComponent.available_bonding_strategies.keys()
-                        )
-                    )
+                    "Bonding strategy not supported. Please supply a name of a NearNeighbor "
+                    f"subclass, choose from: {valid_subclasses}"
                 )
             else:
                 bonding_strategy_kwargs = bonding_strategy_kwargs or {}
@@ -1012,10 +990,10 @@ class StructureMoleculeComponent(MPComponent):
                             (x[0], x[1]): x[2]
                             for x in bonding_strategy_kwargs["cut_off_dict"]
                         }
-                bonding_strategy = StructureMoleculeComponent.available_bonding_strategies[
-                    bonding_strategy
-                ](
-                    **bonding_strategy_kwargs
+                bonding_strategy = (
+                    StructureMoleculeComponent.available_bonding_strategies[
+                        bonding_strategy
+                    ](**bonding_strategy_kwargs)
                 )
                 try:
                     with warnings.catch_warnings():
@@ -1028,7 +1006,7 @@ class StructureMoleculeComponent(MPComponent):
                             graph = MoleculeGraph.with_local_env_strategy(
                                 input, bonding_strategy, reorder=False
                             )
-                except:
+                except Exception:
                     # for some reason computing bonds failed, so let's not have any bonds(!)
                     if isinstance(input, Structure):
                         graph = StructureGraph.with_empty_graph(input)
@@ -1039,8 +1017,8 @@ class StructureMoleculeComponent(MPComponent):
 
     @staticmethod
     def _get_struct_or_mol(
-        graph: Union[StructureGraph, MoleculeGraph, Structure, Molecule]
-    ) -> Union[Structure, Molecule]:
+        graph: StructureGraph | MoleculeGraph | Structure | Molecule,
+    ) -> Structure | Molecule:
         if isinstance(graph, StructureGraph):
             return graph.structure
         elif isinstance(graph, MoleculeGraph):
@@ -1052,7 +1030,7 @@ class StructureMoleculeComponent(MPComponent):
 
     @staticmethod
     def get_scene_and_legend(
-        graph: Optional[Union[StructureGraph, MoleculeGraph]],
+        graph: StructureGraph | MoleculeGraph | None,
         color_scheme=DEFAULTS["color_scheme"],
         color_scale=None,
         radius_strategy=DEFAULTS["radius_strategy"],
@@ -1063,7 +1041,7 @@ class StructureMoleculeComponent(MPComponent):
         scene_additions=None,
         show_compass=DEFAULTS["show_compass"],
         group_by_site_property=None,
-    ) -> Tuple[Scene, Dict[str, str]]:
+    ) -> tuple[Scene, dict[str, str]]:
 
         scene = Scene(name="StructureMoleculeComponentScene")
 
@@ -1107,32 +1085,8 @@ class StructureMoleculeComponent(MPComponent):
 
         return scene_json, legend.get_legend()
 
-    def screenshot_layout(self):
-        """
-        :return: A layout including a button to trigger a screenshot download.
-        """
-        return self._sub_layouts["screenshot"]
-
-    def options_layout(self):
-        """
-        :return: A layout including options to change the appearance, bonding, etc.
-        """
-        return self._sub_layouts["options"]
-
     def title_layout(self):
         """
         :return: A layout including the composition of the structure/molecule as a title.
         """
         return self._sub_layouts["title"]
-
-    def legend_layout(self):
-        """
-        :return: A layout including a legend for the structure/molecule.
-        """
-        return self._sub_layouts["legend"]
-
-    def download_layout(self):
-        """
-        :return: A layout including a download button to download the structure/molecule.
-        """
-        return self._sub_layouts["download"]
