@@ -1,19 +1,13 @@
+from __future__ import annotations
+
 import traceback
 import warnings
-from ast import literal_eval
-from collections import defaultdict
-from json import JSONDecodeError, loads
-from typing import Dict, List, Optional, Tuple, Union
 
 import dash
-from dash import dcc
 import dash_daq as daq
-from dash import html
-from dash import dash_table as dt
-import numpy as np
-from dash.dependencies import ALL, Input, Output, State
+from dash import dcc, html
+from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
-
 from pymatgen.transformations.transformation_abc import AbstractTransformation
 
 from crystal_toolkit.core.mpcomponent import MPComponent
@@ -24,20 +18,14 @@ from crystal_toolkit.helpers.layouts import (
     MessageContainer,
     MessageHeader,
     Reveal,
-    add_label_help,
 )
 from crystal_toolkit.settings import SETTINGS
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
-
 
 class TransformationComponent(MPComponent):
     def __init__(self, input_structure_component_id: str, *args, **kwargs):
 
-        if self.__class__.__name__ != f"{self.transformation.__name__}Component":
+        if type(self).__name__ != f"{self.transformation.__name__}Component":
             # sanity check, enforcing conventions
             raise NameError(
                 f"Class has to be named corresponding to the underlying "
@@ -54,9 +42,7 @@ class TransformationComponent(MPComponent):
 
     @property
     def is_one_to_many(self) -> bool:
-        """
-        This should reflect the underlying transformation.
-        """
+        """This should reflect the underlying transformation."""
         # need to initialize transformation to access property, which isn't
         # possible in all cases without necessary kwargs, which is why
         # we duplicate the property here
@@ -146,10 +132,9 @@ class TransformationComponent(MPComponent):
 
         return container
 
-    def options_layouts(self, state=None, structure=None) -> List[html.Div]:
-        """
-        Return a layout to change the transformation options (that is,
-        that controls the args and kwargs that will be passed to pymatgen).
+    def options_layouts(self, state=None, structure=None) -> list[html.Div]:
+        """Return a layout to change the transformation options (that is, that controls the args and
+        kwargs that will be passed to pymatgen).
 
         The "state" option is so that the controls can be populated appropriately
         using existing args and kwargs, e.g. when restoring the control panel
@@ -173,10 +158,9 @@ class TransformationComponent(MPComponent):
         raise NotImplementedError
 
     def get_preview_layout(self, struct_in, struct_out):
-        """
-        Override this method to give a layout that previews the transformation.
-        Has beneficial side effect of priming the transformation cache when
-        entire transformation pipeline is enabled.
+        """Override this method to give a layout that previews the transformation. Has beneficial
+        side effect of priming the transformation cache when entire transformation pipeline is
+        enabled.
 
         :param struct_in: input Structure
         :param struct_out: transformed Structure
@@ -195,7 +179,7 @@ class TransformationComponent(MPComponent):
                 struct = transformation.apply_transformation(struct)
             except Exception as exc:
                 error_title = (
-                    f'Failed to apply "{transformation.__class__.__name__}" '
+                    f'Failed to apply "{type(transformation).__name__}" '
                     f"transformation: {exc}"
                 )
                 traceback_info = Reveal(
@@ -243,13 +227,15 @@ class TransformationComponent(MPComponent):
         )
         @cache.memoize(
             timeout=60 * 60 * 24,
-            make_name=lambda x: f"{self.__class__.__name__}_{x}_cached",
+            make_name=lambda x: f"{type(self).__name__}_{x}_cached",
         )
         def update_transformation(enabled, states):
 
             # TODO: move callback inside AllTransformationsComponent for efficiency?
 
             kwargs = self.reconstruct_kwargs_from_state(dash.callback_context.states)
+            # for debug
+            # print("transformation kwargs", kwargs)
 
             if not enabled:
                 input_state = (False,) * len(states)
@@ -281,12 +267,19 @@ class TransformationComponent(MPComponent):
 class AllTransformationsComponent(MPComponent):
     def __init__(
         self,
-        transformations: Optional[List[str]] = None,
-        input_structure_component: Optional[MPComponent] = None,
+        transformations: list[str] | None = None,
+        input_structure_component: MPComponent | None = None,
         *args,
         **kwargs,
     ):
+        """Create a component that can manage multiple transformations in a user-defined order.
 
+        :param transformations: if provided, only offer a subset of available
+            transformations, provide as a string of the given transformation name
+        :param input_structure_component: will supply the structure to transform
+        """
+
+        # get available transformations
         subclasses = TransformationComponent.__subclasses__()
         subclass_names = [s.__name__ for s in subclasses]
 
@@ -306,11 +299,13 @@ class AllTransformationsComponent(MPComponent):
             self.links["input_structure"] = input_structure_component.id()
         self.create_store("input_structure")
 
+        self.create_store("enabled-transformations", initial_data=[])
+
         transformations = [
             t(input_structure_component_id=self.id("input_structure"))
             for t in transformations
         ]
-        self.transformations = {t.__class__.__name__: t for t in transformations}
+        self.transformations = {type(t).__name__: t for t in transformations}
 
     @property
     def _sub_layouts(self):
@@ -370,11 +365,12 @@ class AllTransformationsComponent(MPComponent):
 
                 struct = transformation.apply_transformation(struct)
             except Exception as exc:
-                error_title = (
-                    f'Failed to apply "{transformation.__class__.__name__}" '
+                error_title = html.Span(
+                    f'Failed to apply "{type(transformation).__name__}" '
                     f"transformation: {exc}"
                 )
                 traceback_info = Reveal(
+                    id=self.id("Error"),
                     title=html.B("Traceback"),
                     children=[dcc.Markdown(traceback.format_exc())],
                 )
@@ -385,12 +381,15 @@ class AllTransformationsComponent(MPComponent):
         @app.callback(
             Output(self.id("transformation_options"), "children"),
             [
-                Input(self.id("choices"), "value"),
                 Input(self.id("input_structure"), "data"),
+                Input(self.id("choices"), "value"),
             ],
             [State(t.id(), "data") for t in self.transformations.values()],
         )
-        def show_transformation_options(values, structure, *args):
+        def show_transformation_options(structure, values, *args):
+
+            # for debug
+            # print(dash.callback_context.triggered)
 
             values = values or []
 
@@ -408,11 +407,25 @@ class AllTransformationsComponent(MPComponent):
             return [transformation_options]
 
         @app.callback(
-            [Output(self.id(), "data"), Output(self.id("error"), "children")],
+            Output(self.id("enabled-transformations"), "data"),
+            Input(self.id("choices"), "value"),
+        )
+        def set_enabled_transformations(value):
+            """This is due to an unfortunate but noisy bug that complains that this specific input
+            is not present in the layout on load.
+            """
+            return value
+
+        # TODO: make an error store too
+
+        @app.callback(
+            # [
+            Output(self.id(), "data"),
+            # Output(self.id("error"), "children")],
             [Input(t.id(), "data") for t in self.transformations.values()]
             + [
                 Input(self.id("input_structure"), "data"),
-                Input(self.id("choices"), "value"),
+                Input(self.id("enabled-transformations"), "data"),
             ],
         )
         def run_transformations(*args):
@@ -424,6 +437,9 @@ class AllTransformationsComponent(MPComponent):
             user_visible_transformations = args[-1]
             struct = self.from_data(args[-2])
 
+            # for debug
+            # print("input struct", struct)
+
             errors = []
 
             transformations = []
@@ -432,7 +448,7 @@ class AllTransformationsComponent(MPComponent):
                     transformations.append(transformation)
 
             if not transformations:
-                return struct, html.Div()
+                return struct  # , html.Div()
 
             for transformation_data in transformations:
 
@@ -478,7 +494,10 @@ class AllTransformationsComponent(MPComponent):
                     ]
                 )
 
-            return struct, error_msg
+            # for debug
+            # print("transformed struct", struct)
+
+            return struct  # , error_msg
 
         # callback to take all transformations
         # and also state of which transformations are user-visible (+ their order)
