@@ -1,13 +1,8 @@
-from dash import dcc
 from dash import html
-
-from dash.dependencies import Input, Output, State
-
-from crystal_toolkit.helpers.layouts import Label
-from crystal_toolkit.components.transformations.core import TransformationComponent
-
 from pymatgen.transformations.advanced_transformations import SlabTransformation
 
+from crystal_toolkit.components.transformations.core import TransformationComponent
+
 
 class SlabTransformationComponent(TransformationComponent):
     @property
@@ -16,7 +11,7 @@ class SlabTransformationComponent(TransformationComponent):
 
     @property
     def description(self):
-        return """Create a slab from a structure, where a "slab" is a crystal 
+        return """Create a slab from a structure, where a "slab" is a crystal
 surface that is still periodic in all three dimensions but has a large artificial
 vacuum inserted so that the properties of the crystal surface can be studied.
 """
@@ -45,6 +40,7 @@ vacuum inserted so that the properties of the crystal surface can be studied.
             kwarg_label="miller_index",
             state=state,
             help_str="The surface plane defined by its Miller index (h, k, l)",
+            is_int=True,
             shape=(3,),
         )
 
@@ -54,7 +50,7 @@ vacuum inserted so that the properties of the crystal surface can be studied.
             state=state,
             help_str="Minimum slab size in Ångstroms (or number of planes of atoms if "
             '"Use plane units" enabled)',
-            shape=(3,),
+            shape=(),
         )
 
         min_vacuum_size = self.get_numerical_input(
