@@ -1,17 +1,6 @@
-from dash import dcc
-from dash import html
-from dash import dash_table as dt
-
-from dash.dependencies import Input, Output, State
-
-from crystal_toolkit.helpers.layouts import Label
-from crystal_toolkit.components.transformations.core import TransformationComponent
-
-from pymatgen.core.periodic_table import Specie, Element
-from pymatgen.core.structure import Structure
 from pymatgen.transformations.standard_transformations import SubstitutionTransformation
 
-from ast import literal_eval
+from crystal_toolkit.components.transformations.core import TransformationComponent
 
 
 class SubstitutionTransformationComponent(TransformationComponent):
@@ -49,7 +38,7 @@ and copper). Please consult the pymatgen documentation for more information.
             state=state,
             help_str="A mapping from an original species (element or element with oxidation state, e.g. O or O2-) "
             "to a new species (element, element with oxidation state, or a composition, e.g. O or O2- or "
-            '{"Au": 0.5, "Cu": 0.5}). In pymatgen, these are Element, Specie and Composition classes '
+            '{"Au": 0.5, "Cu": 0.5}). In pymatgen, these are Element, Species and Composition classes '
             "respectively.",
             key_name="Original Species",
             value_name="New Species",
