@@ -1,15 +1,11 @@
-import os
-
-from dash import dcc
-from dash import html
 import plotly.graph_objs as go
-
+from dash import dcc, html
 from dash.dependencies import Input, Output, State
 from dash.exceptions import PreventUpdate
 
 from crystal_toolkit.core.mpcomponent import MPComponent
 from crystal_toolkit.core.panelcomponent import PanelComponent
-from crystal_toolkit.helpers.layouts import *
+from crystal_toolkit.helpers.layouts import MessageBody, MessageContainer
 
 # Author: Matthew McDermott
 # Contact: mcdermott@lbl.gov
@@ -147,9 +143,9 @@ class XASComponent(MPComponent):
             if not element or not elements:
                 raise PreventUpdate
 
-            url_path = "/materials/" + mpid["mpid"] + "/xas/" + element
+            url_path = f"/materials/{mpid['mpid']}/xas/{element}"
 
-            from mp_api.matproj import MPRester
+            from mp_api.client import MPRester
 
             with MPRester() as mpr:
                 data = mpr._make_request(url_path)  # querying MP database via MAPI
