@@ -1,41 +1,36 @@
-from pymatgen.core.periodic_table import Specie, Element
-from pymatgen.core.structure import Molecule
-from pymatgen.core.structure import SiteCollection, Site
-from pymatgen.analysis.molecule_structure_comparator import CovalentRadius
-from pymatgen.util.string import unicodeify_species
+from __future__ import annotations
 
+import os
+import warnings
+from collections import defaultdict
+from itertools import chain
+from typing import Any, cast
+
+import numpy as np
+from matplotlib.cm import get_cmap
 from monty.json import MSONable
 from monty.serialization import loadfn
-
-from itertools import chain
-from collections import defaultdict
-
-from palettable.colorbrewer.qualitative import Set1_9, Set2_8
+from palettable.colorbrewer.qualitative import Set1_9
+from pymatgen.analysis.molecule_structure_comparator import CovalentRadius
+from pymatgen.core.periodic_table import Element, Species
+from pymatgen.core.structure import Molecule, Site, SiteCollection
+from pymatgen.util.string import unicodeify_species
 from sklearn.preprocessing import LabelEncoder
-from matplotlib.cm import get_cmap
 from webcolors import html5_parse_legacy_color, html5_serialize_simple_color
 
-from typing import Union, Optional, Tuple, Dict, List, Any
-
-import warnings
-import numpy as np
-import os
-
 # element colors forked from pymatgen
 module_dir = os.path.dirname(os.path.abspath(__file__))
 EL_COLORS = loadfn(os.path.join(module_dir, "ElementColorSchemes.yaml"))
 
 
 class Legend(MSONable):
-    """
-    Help generate a legend (colors and radii) for a Structure or Molecule
-    such that colors and radii can be displayed for the appropriate species.
+    """Help generate a legend (colors and radii) for a Structure or Molecule such that colors and
+    radii can be displayed for the appropriate species.
 
-    Note that species themselves have a color (for example, Oxygen is typically
-    red), but that we might also want to color-code by site properties (for example,
-    magnetic moment), thus this class has to take into account both the species
-    present and its context (the specific site the species is at) to correctly
-    generate the legend.
+    Note that species themselves have a color (for example, Oxygen is typically red), but that we
+    might also want to color-code by site properties (for example, magnetic moment), thus this class
+    has to take into account both the species present and its context (the specific site the species
+    is at) to correctly generate the legend.
     """
 
     default_color_scheme = "Jmol"
@@ -46,16 +41,14 @@ class Legend(MSONable):
 
     def __init__(
         self,
-        site_collection: Union[SiteCollection, Site],
+        site_collection: SiteCollection | Site,
         color_scheme: str = "Jmol",
         radius_scheme: str = "uniform",
         cmap: str = "coolwarm",
-        cmap_range: Optional[Tuple[float, float]] = None,
+        cmap_range: tuple[float, float] | None = None,
     ):
-        """
-        Create a legend for a given SiteCollection to choose how to
-        display colors and radii for the given sites and the species
-        on those sites.
+        """Create a legend for a given SiteCollection to choose how to display colors and radii for
+        the given sites and the species on those sites.
 
         If a site has a "display_color" or "display_radius" site
         property defined, this can be used to manually override the
@@ -74,7 +67,7 @@ class Legend(MSONable):
             "van_der_waals", "atomic_calculated", "uniform"
             cmap: only used if color_mode is set to a scalar site
             property, defines the matplotlib color map to use, by
-            default is blue-white-red for negative to postive values
+            default is blue-white-red for negative to positive values
             cmap_range: only used if color_mode is set to a scalar site
             property, defines the minimum and maximum values of the
             color scape
@@ -137,42 +130,38 @@ class Legend(MSONable):
         self.color_scheme = color_scheme
         self.radius_scheme = radius_scheme
         self.cmap = cmap
-        self.cmap_range = cmap_range
+        self.cmap_range = cast(tuple[float, float], cmap_range)
 
     @staticmethod
     def generate_accessible_color_scheme_on_the_fly(
         site_collection: SiteCollection,
-    ) -> Dict[str, Dict[str, Tuple[int, int, int]]]:
-        """
-        e.g. for a color scheme more appropriate for people with color blindness
+    ) -> dict[str, dict[str, tuple[int, int, int]]]:
+        """E.g. for a color scheme more appropriate for people with color blindness.
 
         Args:
             site_collection: SiteCollection
 
         Returns: A dictionary in similar format to EL_COLORS
-
         """
 
         color_scheme = {}
 
         all_species = set(
-            chain.from_iterable(
-                comp.keys() for comp in site_collection.species_and_occu
-            )
+            chain.from_iterable(comp for comp in site_collection.species_and_occu)
         )
-        all_elements = sorted([sp.as_dict()["element"] for sp in all_species])
+        all_elements = sorted(sp.as_dict()["element"] for sp in all_species)
 
         # thanks to https://doi.org/10.1038/nmeth.1618
         palette = [
             (0, 0, 0),  # 0, black
             (230, 159, 0),  # 1, orange
             (86, 180, 233),  # 2, sky blue
-            (0, 158, 115),  #  3, bluish green
+            (0, 158, 115),  # 3, bluish green
             (240, 228, 66),  # 4, yellow
             (0, 114, 178),  # 5, blue
-            (213, 94, 0),  # 6, vermillion
+            (213, 94, 0),  # 6, vermilion
             (204, 121, 167),  # 7, reddish purple
-            (255, 255, 255),  #  8, white
+            (255, 255, 255),  # 8, white
         ]
 
         # similar to CPK, mapping element to palette index
@@ -197,7 +186,7 @@ class Legend(MSONable):
             )
 
         preferred_elements_present = [
-            el for el in all_elements if el in preferred_colors.keys()
+            el for el in all_elements if el in preferred_colors
         ]
 
         colors_assigned = []
@@ -206,9 +195,7 @@ class Legend(MSONable):
                 color_scheme[el] = palette[preferred_colors[el]]
                 colors_assigned.append(preferred_colors[el])
 
-        remaining_elements = [
-            el for el in all_elements if el not in color_scheme.keys()
-        ]
+        remaining_elements = [el for el in all_elements if el not in color_scheme]
         remaining_palette = [
             c for idx, c in enumerate(palette) if idx not in colors_assigned
         ]
@@ -222,15 +209,13 @@ class Legend(MSONable):
     @staticmethod
     def generate_categorical_color_scheme_on_the_fly(
         site_collection: SiteCollection, site_prop_types
-    ) -> Dict[str, Dict[str, Tuple[int, int, int]]]:
-        """
-        e.g. for Wykcoff
+    ) -> dict[str, dict[str, tuple[int, int, int]]]:
+        """e.g. for Wyckoff.
 
         Args:
             site_collection: SiteCollection
 
         Returns: A dictionary in similar format to EL_COLORS
-
         """
 
         color_scheme = {}
@@ -240,13 +225,13 @@ class Legend(MSONable):
         for site_prop_name in site_prop_types.get("categorical", []):
 
             props = np.array(site_collection.site_properties[site_prop_name])
-            props[props == None] = "None"
+            props[props is None] = "None"
 
             le = LabelEncoder()
             le.fit(props)
             transformed_props = le.transform(props)
 
-            # if we have more categories than availiable colors,
+            # if we have more categories than available colors,
             # arbitrarily group some categories together
             if len(set(props)) > len(palette):
                 warnings.warn(
@@ -262,17 +247,15 @@ class Legend(MSONable):
 
         return color_scheme
 
-    def get_color(self, sp: Union[Specie, Element], site: Optional[Site] = None) -> str:
-        """
-        Get a color to render a specific species. Optionally, you can provide
-        a site for context, since ...
+    def get_color(self, sp: Species | Element, site: Site | None = None) -> str:
+        """Get a color to render a specific species. Optionally, you can provide a site for context,
+        since ...
 
         Args:
-            sp: Specie or Element
+            sp: Species or Element
             site: Site
 
         Returns: Color
-
         """
 
         # allow manual override by user
@@ -307,8 +290,7 @@ class Legend(MSONable):
                 cmap = get_cmap(self.cmap)
 
                 # normalize in [0, 1] range, as expected by cmap
-                prop_min = self.cmap_range[0]
-                prop_max = self.cmap_range[1]
+                prop_min, prop_max = self.cmap_range
                 prop_normed = (prop - prop_min) / (prop_max - prop_min)
 
                 color = [int(c * 255) for c in cmap(prop_normed)[0:3]]
@@ -340,9 +322,7 @@ class Legend(MSONable):
 
         return html5_serialize_simple_color(color)
 
-    def get_radius(
-        self, sp: Union[Specie, Element], site: Optional[Site] = None
-    ) -> float:
+    def get_radius(self, sp: Species | Element, site: Site | None = None) -> float:
 
         # allow manual override by user
         if site and "display_radius" in site.properties:
@@ -361,7 +341,7 @@ class Legend(MSONable):
             radius = float(sp.atomic_radius)
         elif (
             self.radius_scheme == "specified_or_average_ionic"
-            and isinstance(sp, Specie)
+            and isinstance(sp, Species)
             and sp.oxi_state
         ):
             radius = float(sp.ionic_radius)
@@ -377,15 +357,15 @@ class Legend(MSONable):
 
         if (not radius) or (not isinstance(radius, float)):
             warnings.warn(
-                "Radius unknown for {} and strategy {}, "
-                "setting to 0.5.".format(sp, self.radius_scheme)
+                f"Radius unknown for {sp} and strategy {self.radius_scheme}, "
+                "setting to 0.5."
             )
             radius = self.fallback_radius
 
         return radius
 
     @staticmethod
-    def analyze_site_props(site_collection: SiteCollection) -> Dict[str, List[str]]:
+    def analyze_site_props(site_collection: SiteCollection) -> dict[str, list[str]]:
         """
         Returns: A dictionary with keys "scalar", "matrix", "vector", "categorical"
         and values of a list of site property names corresponding to each type
@@ -405,10 +385,10 @@ class Legend(MSONable):
         return dict(site_prop_names)
 
     @staticmethod
-    def get_species_str(sp: Union[Specie, Element]) -> str:
+    def get_species_str(sp: Species | Element) -> str:
         """
         Args:
-            sp: Specie or Element
+            sp: Species or Element
 
         Returns: string representation
         """
@@ -416,7 +396,7 @@ class Legend(MSONable):
         # and then move this to pymatgen string utils ...
         return unicodeify_species(str(sp))
 
-    def get_legend(self) -> Dict[str, Any]:
+    def get_legend(self) -> dict[str, Any]:
 
         # decide what we want the labels to be
         if self.color_scheme in ("Jmol", "VESTA", "accessible"):
@@ -432,7 +412,7 @@ class Legend(MSONable):
 
         # first get all our colors for different species
         for site in self.site_collection:
-            for sp, occu in site.species.items():
+            for sp in site.species:
                 legend[self.get_color(sp, site)].append(label(site, sp))
 
         legend = {k: ", ".join(sorted(list(set(v)))) for k, v in legend.items()}
