@@ -1,30 +1,28 @@
+from __future__ import annotations
+
 import logging
-from abc import ABC, abstractmethod
+from abc import ABC
 from ast import literal_eval
+from base64 import b64encode
 from collections import defaultdict
 from itertools import chain
 from json import JSONDecodeError, dumps, loads
-from typing import Dict, List, Optional, Set, Tuple, Union
-from base64 import b64encode
+from typing import Any, Literal
 
 import dash
-from dash import dcc
-from dash import html
-from dash import dash_table as dt
+import dash_mp_components as mpc
 import numpy as np
-from dash.dependencies import ALL, Output
+import plotly.graph_objects as go
+from dash import dash_table as dt
+from dash import dcc, html
+from dash.dependencies import ALL
 from flask_caching import Cache
 from monty.json import MontyDecoder, MSONable
 
 from crystal_toolkit import __version__ as ct_version
-from crystal_toolkit.helpers.layouts import add_label_help, Icon, Button, Loading
+from crystal_toolkit.helpers.layouts import Button, Icon, Loading, add_label_help
 from crystal_toolkit.settings import SETTINGS
 
-try:
-    from typing import Literal
-except ImportError:
-    from typing_extensions import Literal
-
 # fallback cache if Redis etc. isn't set up
 null_cache = Cache(config={"CACHE_TYPE": "null"})
 
@@ -34,9 +32,9 @@ CT_NAMESPACE = "CT"
 
 
 class MPComponent(ABC):
-    """
-    The abstract base class for an MPComponent. MPComponent
-    is designed to help render an MSONable object.
+    """The abstract base class for an MPComponent.
+
+    MPComponent is designed to help render an MSONable object.
     """
 
     # reference to global Dash app
@@ -47,25 +45,22 @@ class MPComponent(ABC):
 
     # used to track all dcc.Stores required for all MPComponents to work
     # keyed by the MPComponent id
-    _app_stores_dict: Dict[str, List[dcc.Store]] = defaultdict(list)
+    _app_stores_dict: dict[str, list[dcc.Store]] = defaultdict(list)
 
     # used to track what individual Dash components are defined
     # by this MPComponent
-    _all_id_basenames: Set[str] = set()
+    _all_id_basenames: set[str] = set()
 
     # used to defer generation of callbacks until app.layout defined
     # can be helpful to callback exceptions retained
-    _callbacks_to_generate: Set["MPComponent"] = set()
+    _callbacks_to_generate: set[MPComponent] = set()
 
     @staticmethod
     def register_app(app: dash.Dash):
-        """
-        This method must be called at least once in your Crystal
-        Toolkit Dash app if you want to enable interactivity with the
-        MPComponents. The "app" variable is a special global
-        variable used by Dash/Flask, and registering it with
-        MPComponent allows callbacks to be registered with the
-        app on instantiation.
+        """This method must be called at least once in your Crystal Toolkit Dash app if you want to
+        enable interactivity with the MPComponents. The "app" variable is a special global variable
+        used by Dash/Flask, and registering it with MPComponent allows callbacks to be registered
+        with the app on instantiation.
 
         Args:
             app: a Dash app instance
@@ -83,19 +78,17 @@ class MPComponent(ABC):
             app.title = "Crystal Toolkit"
 
     @staticmethod
-    def register_cache(cache: Cache):
-        """
-        This method must be called at least once in your
-        Crystal Toolkit Dash app if you want to enable
-        callback caching. Callback caching is one of the
-        easiest ways to see significant performance
-        improvements, especially for callbacks that are
-        computationally expensive.
+    def register_cache(cache: Cache) -> None:
+        """This method must be called at least once in your Crystal Toolkit Dash app if you want to
+        enable callback caching. Callback caching is one of the easiest ways to see significant
+        performance improvements, especially for callbacks that are computationally expensive.
 
         Args:
             cache: a flask_caching Cache instance
         """
-        if cache:
+        if SETTINGS.DEBUG_MODE:
+            cache = null_cache
+        elif cache:
             MPComponent.cache = cache
         else:
             MPComponent.cache = Cache(
@@ -107,8 +100,7 @@ class MPComponent(ABC):
 
         if not MPComponent.app:
             raise ValueError(
-                "Please register the Dash app with Crystal Toolkit "
-                "using register_app()."
+                "Please register the Dash app with Crystal Toolkit using register_app()."
             )
 
         # layout_str = str(layout)
@@ -137,11 +129,8 @@ class MPComponent(ABC):
 
     @staticmethod
     def all_app_stores() -> html.Div:
-        """
-        This must be included somewhere in your
-        Crystal Toolkit Dash app's layout for
-        interactivity to work. This is a hidden element
-        that contains the MSON for each MPComponent.
+        """This must be included somewhere in your Crystal Toolkit Dash app's layout for
+        interactivity to work. This is a hidden element that contains the MSON for each MPComponent.
 
         Returns: a html.Div Dash Layout
         """
@@ -151,14 +140,13 @@ class MPComponent(ABC):
 
     def __init__(
         self,
-        default_data: Optional[Union[MSONable, Dict, str]] = None,
-        id: Optional[str] = None,
-        links: Optional[Dict[str, str]] = None,
+        default_data: MSONable | dict | str | None = None,
+        id: str | None = None,
+        links: dict[str, str] | None = None,
         storage_type: Literal["memory", "local", "session"] = "memory",
         disable_callbacks: bool = False,
     ):
-        """
-        The abstract base class for an MPComponent.
+        """The abstract base class for an MPComponent.
 
         The MPComponent is designed to help render any MSONable object,
         for example many of the objects in pymatgen (Structure, PhaseDiagram, etc.)
@@ -187,7 +175,7 @@ class MPComponent(ABC):
         are _sub_layouts and generate_callbacks().
 
         Args:
-            default_data: inital contents for the component, can be None
+            default_data: initial contents for the component, can be None
             id: a unique id, required if multiple of the same type of
             MPComponent are included in an app
             links: if set, will set store contents from the stores of another
@@ -212,13 +200,13 @@ class MPComponent(ABC):
         if id is None:
             # TODO: this could lead to duplicate ids and an error, but if
             # setting random ids, this could also lead to undefined behavior
-            id = f"{CT_NAMESPACE}{self.__class__.__name__}"
+            id = f"{CT_NAMESPACE}{type(self).__name__}"
         elif not id.startswith(CT_NAMESPACE):
             id = f"{CT_NAMESPACE}{id}"
         MPComponent._all_id_basenames.add(id)
 
         self._id = id
-        self._all_ids = set()
+        self._all_ids: set[str] = set()
         self._stores = {}
         self._initial_data = {}
 
@@ -233,7 +221,7 @@ class MPComponent(ABC):
             # callbacks generated as final step by crystal_toolkit_layout()
             self._callbacks_to_generate.add(self)
 
-        self.logger = logging.getLogger(self.__class__.__name__)
+        self.logger = logging.getLogger(type(self).__name__)
 
     def id(
         self,
@@ -242,11 +230,9 @@ class MPComponent(ABC):
         idx=False,
         hint=None,
         is_store: bool = False,
-    ) -> Union[str, Dict[str, str]]:
-        """
-        Generate an id from a name combined with the
-        base id of the MPComponent itself, useful for generating
-        ids of individual components in the layout.
+    ) -> str | dict[str, str]:
+        """Generate an id from a name combined with the base id of the MPComponent itself, useful
+        for generating ids of individual components in the layout.
 
         In the special case of the id of an element that is used to re-construct
         a keyword argument for a specific class, it will store information necessary
@@ -295,14 +281,12 @@ class MPComponent(ABC):
     def create_store(
         self,
         name: str,
-        initial_data: Optional[Union[MSONable, Dict, str]] = None,
+        initial_data: MSONable | dict | str | None = None,
         storage_type: Literal["memory", "local", "session"] = "memory",
         debug_clear: bool = False,
-    ):
-        """
-        Generate a dcc.Store to hold something (MSONable object, Dict
-        or string), and register it so that it will be included in the
-        Dash app automatically.
+    ) -> None:
+        """Generate a dcc.Store to hold something (MSONable object, Dict or string), and register it
+        so that it will be included in the Dash app automatically.
 
         The initial data will be stored in a class attribute as
         self._initial_data[name].
@@ -330,7 +314,7 @@ class MPComponent(ABC):
         MPComponent._app_stores_dict[self.id()].append(store)
 
     @property
-    def initial_data(self):
+    def initial_data(self) -> dict[str, Any]:
         """
         :return: Initial data for all the stores defined by component,
         keyed by store name.
@@ -338,57 +322,51 @@ class MPComponent(ABC):
         return self._initial_data
 
     @staticmethod
-    def from_data(data):
-        """
-        Converts the contents of a dcc.Store back into a Python object.
+    def from_data(data: dict[str, Any]) -> MPComponent:
+        """Converts the contents of a dcc.Store back into a Python object.
+
         :param data: contents of a dcc.Store created by to_data
         :return: a Python object
         """
         return loads(dumps(data), cls=MontyDecoder)
 
     @property
-    def all_stores(self) -> List[str]:
+    def all_stores(self) -> list[str]:
         """
         :return: List of all store ids generated by this component
         """
-        return list(self._stores.keys())
+        return list(self._stores)
 
     @property
-    def all_ids(self) -> List[str]:
+    def all_ids(self) -> list[str]:
         """
         :return: List of all ids generated by this component
         """
         return list(
-            [
-                component_id
-                for component_id in self._all_ids
-                if component_id not in self.all_stores
-            ]
+            component_id
+            for component_id in self._all_ids
+            if component_id not in self.all_stores
         )
 
-    def __repr__(self):
-        return f"{self.id()}<{self.__class__.__name__}>"
+    def __repr__(self) -> str:
+        return f"{self.id()}<{type(self).__name__}>"
 
-    def __str__(self):
+    def __str__(self) -> str:
         ids = "\n".join(
             [f"* {component_id}  " for component_id in sorted(self.all_ids)]
         )
         stores = "\n".join([f"* {store}  " for store in sorted(self.all_stores)])
-        layouts = "\n".join(
-            [f"* {layout}  " for layout in sorted(self._sub_layouts.keys())]
-        )
+        layouts = "\n".join([f"* {layout}  " for layout in sorted(self._sub_layouts)])
 
-        return f"""{self.id()}<{self.__class__.__name__}>  \n
+        return f"""{self.id()}<{type(self).__name__}>  \n
 IDs:  \n{ids}  \n
 Stores:  \n{stores}  \n
 Sub-layouts:  \n{layouts}"""
 
     @property
-    def _sub_layouts(self):
-        """
-        Layouts associated with this component, available for book-keeping
-        if your component is complex, so that the layout() method is just
-        assembles individual sub-layouts.
+    def _sub_layouts(self) -> dict[str, dash.development.base_component.Component]:
+        """Layouts associated with this component, available for book-keeping if your component is
+        complex, so that the layout() method is just assembles individual sub-layouts.
 
         :return: A dictionary with names of layouts as keys (str) and Dash
         layouts (e.g. html.Div) as values.
@@ -402,29 +380,28 @@ Sub-layouts:  \n{layouts}"""
         """
         return html.Div(list(self._sub_layouts.values()))
 
-    def generate_callbacks(self, app, cache):
-        """
-        Generate all callbacks associated with the layouts in this app. Assume
-        that "suppress_callback_exceptions" is True, since it is not always
-        guaranteed that all layouts will be displayed to the end user at all
-        times, but it's important the callbacks are defined on the server.
+    def generate_callbacks(self, app, cache) -> None:
+        """Generate all callbacks associated with the layouts in this app.
+
+        Assume that "suppress_callback_exceptions" is True, since it is not always guaranteed that
+        all layouts will be displayed to the end user at all times, but it's important the callbacks
+        are defined on the server.
         """
         return None
 
     def get_numerical_input(
         self,
         kwarg_label: str,
-        default: Optional[Union[int, float, List]] = None,
-        state: Optional[dict] = None,
-        label: Optional[str] = None,
+        default: int | float | list | None = None,
+        state: dict | None = None,
+        label: str | None = None,
         help_str: str = None,
         is_int: bool = False,
-        shape: Tuple[int, ...] = (),
+        shape: tuple[int, ...] = (),
         **kwargs,
-    ):
-        """
-        For Python classes which take matrices as inputs, this will generate
-        a corresponding Dash input layout.
+    ) -> html.Div:
+        """For Python classes which take matrices as inputs, this will generate a corresponding Dash
+        input layout.
 
         :param kwarg_label: The name of the corresponding Python input, this is used
         to name the component.
@@ -502,10 +479,11 @@ Sub-layouts:  \n{layouts}"""
 
         # arrange the input boxes in two dimensions (rows, columns)
         matrix_div_contents = []
-        for row_idx, columns in sorted(matrix_contents.items()):
+        print("matrix_contents", matrix_contents)
+        for column_idx in sorted(matrix_contents):
             row = []
-            for column_idx, element in sorted(columns.items()):
-                row.append(element)
+            for row_idx in sorted(matrix_contents[column_idx]):
+                row.append(matrix_contents[column_idx][row_idx])
             matrix_div_contents.append(html.Div(row))
 
         matrix = html.Div(matrix_div_contents)
@@ -515,30 +493,30 @@ Sub-layouts:  \n{layouts}"""
     def get_slider_input(
         self,
         kwarg_label: str,
-        default: Optional = None,
-        state: Dict = None,
-        label: Optional[str] = None,
+        default: Any | None = None,
+        state: dict = None,
+        label: str | None = None,
         help_str: str = None,
         multiple: bool = False,
         **kwargs,
     ):
 
         state = state or {}
+        # TODO: bug if default == 0
         default = default or state.get(kwarg_label)
 
-        slider_kwargs = dict(
-            tooltip={"placement": "bottom", "always_visible": True}, persistence=False,
-        )
-        slider_kwargs.update(kwargs)
+        # mpc.RangeSlider requires a domain to be specified
+        slider_kwargs = {"domain": [0, default * 2]}
+        slider_kwargs.update(**kwargs)
 
         if multiple:
-            slider_input = dcc.RangeSlider(
+            slider_input = mpc.DualRangeSlider(
                 id=self.id(kwarg_label, is_kwarg=True, hint="slider"),
                 value=default,
                 **slider_kwargs,
             )
         else:
-            slider_input = dcc.Slider(
+            slider_input = mpc.RangeSlider(
                 id=self.id(kwarg_label, is_kwarg=True, hint="slider"),
                 value=default,
                 **slider_kwargs,
@@ -549,22 +527,23 @@ Sub-layouts:  \n{layouts}"""
     def get_bool_input(
         self,
         kwarg_label: str,
-        default: Optional[bool] = None,
-        state: Optional[dict] = None,
-        label: Optional[str] = None,
+        default: bool | None = None,
+        state: dict | None = None,
+        label: str | None = None,
         help_str: str = None,
+        **kwargs,
     ):
-        """
-        For Python classes which take boolean values as inputs, this will generate
-        a corresponding Dash input layout.
+        """For Python classes which take boolean values as inputs, this will generate a
+        corresponding Dash input layout.
 
         :param kwarg_label: The name of the corresponding Python input, this is used
         to name the component.
         :param label: A description for this input.
         :param default: A default value for this input.
-        :param state: Used to set default state for this input, use a dict with the kwarg_label as a key
-        and the default value as a value. Ignored if `default` is set. It can be useful to use
-        `state` if you want to set defaults for multiple inputs from a single dictionary.
+        :param state: Used to set default state for this input, use a dict with the
+            kwarg_label as a key
+        and the default value as a value. Ignored if `default` is set. It can be useful
+            to use `state` if you want to set defaults for multiple inputs from a single dictionary.
         :param help_str: Text for a tooltip when hovering over label.
         :return: a Dash layout
         """
@@ -572,12 +551,11 @@ Sub-layouts:  \n{layouts}"""
         state = state or {}
         default = default or state.get(kwarg_label) or False
 
-        bool_input = dcc.Checklist(
+        bool_input = mpc.Switch(
             id=self.id(kwarg_label, is_kwarg=True, hint="bool"),
-            style={"width": "5rem"},
-            options=[{"label": "", "value": "enabled"}],
-            value=["enabled"] if default else [],
-            persistence=False,
+            value=True if default else False,
+            hasLabel=True,
+            **kwargs,
         )
 
         return add_label_help(bool_input, label, help_str)
@@ -585,16 +563,16 @@ Sub-layouts:  \n{layouts}"""
     def get_choice_input(
         self,
         kwarg_label: str,
-        default: Optional[str] = None,
-        state: Optional[dict] = None,
-        label: Optional[str] = None,
+        default: str | None = None,
+        state: dict | None = None,
+        label: str | None = None,
         help_str: str = None,
-        options: Optional[List[Dict]] = None,
+        options: list[dict] | None = None,
+        clearable: bool = False,
         **kwargs,
     ):
-        """
-        For Python classes which take floats as inputs, this will generate
-        a corresponding Dash input layout.
+        """For Python classes which take pre-defined values as inputs, this will generate a
+        corresponding input layout using mpc.Select.
 
         :param kwarg_label: The name of the corresponding Python input, this is used
         to name the component.
@@ -605,19 +583,19 @@ Sub-layouts:  \n{layouts}"""
         `state` if you want to set defaults for multiple inputs from a single dictionary.
         :param help_str: Text for a tooltip when hovering over label.
         :param options: Options to choose from, as per dcc.Dropdown
+        :param clearable: If True, will allow Dropdown to be cleared after a selection is made.
         :return: a Dash layout
         """
 
         state = state or {}
         default = default or state.get(kwarg_label)
 
-        option_input = dcc.Dropdown(
+        option_input = mpc.Select(
             id=self.id(kwarg_label, is_kwarg=True, hint="literal"),
             options=options if options else [],
             value=default,
-            persistence=False,
-            clearable=False,
-            **kwargs,
+            isClearable=clearable,
+            arbitraryProps={**kwargs},
         )
 
         return add_label_help(option_input, label, help_str)
@@ -625,9 +603,9 @@ Sub-layouts:  \n{layouts}"""
     def get_dict_input(
         self,
         kwarg_label: str,
-        default: Optional = None,
-        state: Optional[dict] = None,
-        label: Optional[str] = None,
+        default: Any | None = None,
+        state: dict | None = None,
+        label: str | None = None,
         help_str: str = None,
         key_name: str = "key",
         value_name: str = "value",
@@ -660,7 +638,7 @@ Sub-layouts:  \n{layouts}"""
 
         return add_label_help(dict_input, label, help_str)
 
-    def get_kwarg_id(self, kwarg_name) -> Dict:
+    def get_kwarg_id(self, kwarg_name) -> dict[str, str]:
         """
 
         :param kwarg_name:
@@ -673,7 +651,7 @@ Sub-layouts:  \n{layouts}"""
             "hint": ALL,
         }
 
-    def get_all_kwargs_id(self) -> Dict:
+    def get_all_kwargs_id(self) -> dict[str, str]:
         """
 
         :return:
@@ -685,9 +663,8 @@ Sub-layouts:  \n{layouts}"""
             state=state, kwarg_labels=[kwarg_name]
         )[kwarg_name]
 
-    def reconstruct_kwargs_from_state(self, state=None, kwarg_labels=None) -> Dict:
-        """
-        Generate
+    def reconstruct_kwargs_from_state(self, state=None, kwarg_labels=None) -> dict:
+        """Generate.
 
         :param state: optional, a Dash callback context input or state
         :param kwarg_labels: optional, parse only a specific kwarg or list of kwargs
@@ -751,11 +728,11 @@ Sub-layouts:  \n{layouts}"""
 
                     try:
                         kwargs[kwarg_label] = literal_eval(str(v))
-                    except ValueError:
+                    except (ValueError, SyntaxError):
                         kwargs[kwarg_label] = str(v)
 
                 elif k_type == "bool":
-                    kwargs[kwarg_label] = bool("enabled" in v)
+                    kwargs[kwarg_label] = v
 
                 elif k_type == "slider":
                     kwargs[kwarg_label] = v
@@ -772,25 +749,30 @@ Sub-layouts:  \n{layouts}"""
                 kwargs[k] = v.tolist()
 
         if SETTINGS.DEBUG_MODE:
-            print(self.__class__.__name__, "kwargs", kwargs)
+            print(type(self).__name__, "kwargs", kwargs)
 
         return kwargs
 
     @staticmethod
-    def datauri_from_fig(
-        fig, fmt: str = "png", width: int = 600, height: int = 400, scale: int = 4
+    def data_uri_from_fig(
+        fig: go.Figure,
+        fmt: str = "png",
+        width: int = 600,
+        height: int = 400,
+        scale: int = 4,
     ) -> str:
-        """
-        Generate a data URI from a Plotly Figure.
+        """Generate a data URI from a Plotly Figure.
 
-        :param fig: Plotly Figure object or corresponding dictionary
-        :param fmt: "png", "jpg", etc. (see PlotlyScope for supported formats)
-        :param width: width in pixels
-        :param height: height in pixels
-        :param scale: scale factor
-        :return:
-        """
+        Args:
+            fig (Figure): Plotly Figure object or corresponding dictionary
+            fmt (str, optional): "png", "jpg", etc. (see PlotlyScope for supported formats). Defaults to "png".
+            width (int, optional): width in pixels. Defaults to 600.
+            height (int, optional): height in pixels. Defaults to 400.
+            scale (int, optional): scale factor. Defaults to 4.
 
+        Returns:
+            str: Data URI containing base64-encoded image.
+        """
         from kaleido.scopes.plotly import PlotlyScope
 
         scope = PlotlyScope()
@@ -802,8 +784,7 @@ Sub-layouts:  \n{layouts}"""
         return f"data:image/{fmt};base64,{image}"
 
     def get_figure_placeholder(self, figure_id: str) -> html.Div:
-        """
-        Get a layout to act as a placeholder for an interactive figure.
+        """Get a layout to act as a placeholder for an interactive figure.
 
         When used with `generate_static_figure_callbacks`, and assuming
         kaleido is installed on the server, a static image placeholder will
