@@ -1,9 +1,11 @@
-from abc import ABC, abstractmethod, abstractproperty
+from __future__ import annotations
+
+from abc import abstractmethod
 from collections import defaultdict
-from dataclasses import dataclass, field, asdict
+from dataclasses import asdict, dataclass, field
 from itertools import chain
 from json import dump
-from typing import List, Optional, Dict, Any
+from typing import Any
 
 """
 This module gives a Python interface to generate JSON for the
@@ -15,12 +17,15 @@ the Scene to the JSON format to pass to CrystalToolkitSceneComponent's data attr
 
 
 class Primitive:
-    """
-    A Mixin class for standard plottable primitive behavior
-    For now, this just enforces some basic mergeability
+    """A Mixin class for standard plottable primitive behavior.
+
+    For now, this just enforces some basic mergeability.
     """
 
-    @abstractproperty
+    positions: tuple
+
+    @property
+    @abstractmethod
     def key(self):
         raise NotImplementedError
 
@@ -29,27 +34,26 @@ class Primitive:
         raise NotImplementedError
 
     @property
-    def bounding_box(self) -> List[List[float]]:
+    def bounding_box(self) -> list[list[float]]:
         x, y, z = zip(*self.positions)
         return [[min(x), min(y), min(z)], [max(x), max(y), max(z)]]
 
 
 @dataclass
 class Scene:
-    """
-    A Scene is defined by its name (a string, does not have to be unique),
-    and its contents (a list of geometric primitives or other Scenes).
+    """A Scene is defined by its name (a string, does not have to be unique), and its contents (a
+    list of geometric primitives or other Scenes).
     """
 
     name: str  # name for the scene, does not have to be unique
     contents: list = field(default_factory=list)
-    origin: List[float] = field(default=(0, 0, 0))
+    origin: tuple[float, float, float] = field(default=(0, 0, 0))
     visible: bool = True
-    _meta: Dict = None
+    lattice: list[list[float]] | None = None
+    _meta: dict | None = None
 
     def __add__(self, other):
-        """
-        For convenience to combine multiple scenes.
+        """For convenience to combine multiple scenes.
 
         No good way to decide what origin to set for the new scene.
 
@@ -57,27 +61,25 @@ class Scene:
         :return:
         """
         return Scene(
-            name=self.name + "_" + other.name,
+            name=f"{self.name}_{other.name}",
             contents=self.contents + other.contents,
             origin=self.origin,
             visible=self.visible,
+            lattice=self.lattice,
             _meta={self.name: self._meta, other.name: other._meta},
         )
 
     def _repr_mimebundle_(self, include=None, exclude=None):
-        """
-        Render Scenes using crystaltoolkit-extension for Jupyter Lab.
-        """
+        """Render Scenes using crystaltoolkit-extension for Jupyter Lab."""
         return {
             "application/vnd.mp.ctk+json": self.to_json(),
-            "text/plain": self.__repr__(),
+            "text/plain": repr(self),
         }
 
     def to_json(self):
-        """
-        Convert a Scene into JSON. It will implicitly assume all None values means
-        that that attribute uses its default value, and so will be removed from
-        the JSON to reduce the file size of the resulting JSON.
+        """Convert a Scene into JSON. It will implicitly assume all None values means that attribute
+        uses its default value, and so will be removed from the JSON to reduce the file size of the
+        resulting JSON.
 
         Note that this function actually returns a Python dict, but in a format
         that can be converted to a JSON string using the standard library JSON
@@ -91,13 +93,11 @@ class Scene:
             name=self.name,
             contents=self.merge_primitives(self.contents),
             origin=self.origin,
+            lattice=self.lattice,
         )
 
         def remove_defaults(scene_dict):
-            """
-            Reduce file size of JSON by removing any key which
-            is just its default value.
-            """
+            """Reduce file size of JSON by removing any key which is just its default value."""
             trimmed_dict = {}
             for k, v in scene_dict.items():
                 if isinstance(v, dict):
@@ -114,15 +114,12 @@ class Scene:
         return remove_defaults(asdict(merged_scene))
 
     def to_plotly_json(self):
-        """
-        Easy way to allow Scene objects to be returned from callbacks.
-        """
+        """Easy way to allow Scene objects to be returned from callbacks."""
         return self.to_json()
 
     def to(self, filename):
-        """
-        Write a Scene to a file. Can be opened by Jupyter Lab if
-        Crystal Toolkit extension installed.
+        """Write a Scene to a file. Can be opened by Jupyter Lab if Crystal Toolkit extension
+        installed.
 
         :param filename: The filename (can include path),
         an extension will be set if not supplied.
@@ -135,10 +132,8 @@ class Scene:
             dump(self.to_json(), f)
 
     @property
-    def bounding_box(self) -> List[List[float]]:
-        """
-        Returns the bounding box coordinates
-        """
+    def bounding_box(self) -> list[list[float]]:
+        """Returns the bounding box coordinates."""
         if len(self.contents) > 0:
             min_list, max_list = zip(*[p.bounding_box for p in self.contents])
             min_x, min_y, min_z = map(min, list(zip(*min_list)))
@@ -150,13 +145,13 @@ class Scene:
 
     @staticmethod
     def merge_primitives(primitives):
-        """
-        If primitives are of the same type but differ only in position, they
-        are merged together. This is a small optimization, has not been benchmarked.
+        """If primitives are of the same type but differ only in position, they are merged together.
+        This is a small optimization, has not been benchmarked.
+
         :param primitives: list of primitives (Spheres, Cylinders, etc.)
         :return: list of primitives
         """
-        mergable = defaultdict(list)
+        mergeable = defaultdict(list)
         remainder = []
 
         for primitive in primitives:
@@ -164,20 +159,20 @@ class Scene:
                 primitive.contents = Scene.merge_primitives(primitive.contents)
                 remainder.append(primitive)
             elif isinstance(primitive, Primitive):
-                mergable[primitive.key].append(primitive)
+                mergeable[primitive.key].append(primitive)
             else:
                 remainder.append(primitive)
 
-        merged = [v[0].merge(v) for v in mergable.values()]
+        merged = [v[0].merge(v) for v in mergeable.values()]
 
         return merged + remainder
 
 
 @dataclass
 class Spheres(Primitive):
-    """
-    Create a set of spheres. All spheres will have the same color, radius and
-    segment size (if only drawing a section of a sphere).
+    """Create a set of spheres. All spheres will have the same color, radius and segment size (if
+    only drawing a section of a sphere).
+
     :param positions: This is a list of lists corresponding to the vector
     positions of the spheres.
     :param color: Sphere color as a hexadecimal string, e.g. #ff0000
@@ -192,17 +187,17 @@ class Spheres(Primitive):
     and trigger and event
     """
 
-    positions: List[List[float]]
-    _animate: Optional[List[List[float]]] = None
-    color: Optional[str] = None
-    radius: Optional[float] = None
-    phiStart: Optional[float] = None
-    phiEnd: Optional[float] = None
+    positions: list[list[float]]
+    _animate: list[list[float]] | None = None
+    color: str | None = None
+    radius: float | None = None
+    phiStart: float | None = None
+    phiEnd: float | None = None
     type: str = field(default="spheres", init=False)  # private field
-    visible: bool = None
-    tooltip: str = None
+    visible: bool | None = None
+    tooltip: str | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
@@ -214,11 +209,6 @@ class Spheres(Primitive):
         new_positions = list(
             chain.from_iterable([sphere.positions for sphere in sphere_list])
         )
-        new__animate = list(
-            chain.from_iterable(
-                [sphere._animate for sphere in sphere_list if sphere._animate]
-            )
-        )
         return cls(
             positions=new_positions,
             color=sphere_list[0].color,
@@ -233,13 +223,14 @@ class Spheres(Primitive):
 
 @dataclass
 class Ellipsoids(Primitive):
-    """
-    Create a set of ellipsoids. All ellipsoids will have the same color, radius and
-    segment size (if only drawing a section of a ellipsoid).
+    """Create a set of ellipsoids. All ellipsoids will have the same color, radius and segment size
+    (if only drawing a section of a ellipsoid).
+
     :param scale: This is the scale to apply to the x,y and z axis of the ellipsoid prior to rotation to the target axes
     :param positions: This is a list of lists corresponding to the vector
     positions of the ellipsoids.
-    :param rotate_to: This is a list of vectors that specify the direction the major axis of the ellipsoid should point towards. The major axis is the z-axis: (0,0,1)
+    :param rotate_to: This is a list of vectors that specify the direction the major axis of the ellipsoid should point
+        towards. The major axis is the z-axis: (0,0,1)
     :param color: Ellipsoid color as a hexadecimal string, e.g. #ff0000
     :param phiStart: Start angle in radians if drawing only a section of the
     ellipsoid, defaults to 0
@@ -251,17 +242,17 @@ class Ellipsoids(Primitive):
     and trigger and event
     """
 
-    scale: List[float]
-    positions: List[List[float]]
-    rotate_to: List[List[float]]
-    _animate: Optional[List[List[float]]] = None
-    color: Optional[str] = None
-    phiStart: Optional[float] = None
-    phiEnd: Optional[float] = None
+    scale: list[float]
+    positions: list[list[float]]
+    rotate_to: list[list[float]]
+    _animate: list[list[float]] | None = None
+    color: str | None = None
+    phiStart: float | None = None
+    phiEnd: float | None = None
     type: str = field(default="ellipsoids", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
@@ -300,9 +291,8 @@ class Ellipsoids(Primitive):
 
 @dataclass
 class Cylinders(Primitive):
-    """
-    Create a set of cylinders. All cylinders will have the same color and
-    radius.
+    """Create a set of cylinders. All cylinders will have the same color and radius.
+
     :param positionPairs: This is a list of pairs of lists corresponding to the
     start and end position of the cylinder.
     :param color: Cylinder color as a hexadecimal string, e.g. #ff0000
@@ -313,15 +303,15 @@ class Cylinders(Primitive):
     and trigger and event
     """
 
-    positionPairs: List[List[List[float]]]
-    _animate: Optional[List[List[List[float]]]] = None
-    color: Optional[str] = None
-    radius: Optional[float] = None
+    positionPairs: list[list[list[float]]]
+    _animate: list[list[list[float]]] | None = None
+    color: str | None = None
+    radius: float | None = None
     type: str = field(default="cylinders", init=False)  # private field
-    visible: bool = None
-    tooltip: str = None
+    visible: bool | None = None
+    tooltip: str | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
@@ -334,11 +324,6 @@ class Cylinders(Primitive):
         new_positionPairs = list(
             chain.from_iterable([cylinder.positionPairs for cylinder in cylinder_list])
         )
-        new__animate = list(
-            chain.from_iterable(
-                [cylinder._animate for cylinder in cylinder_list if cylinder._animate]
-            )
-        )
 
         return cls(
             positionPairs=new_positionPairs,
@@ -348,15 +333,15 @@ class Cylinders(Primitive):
         )
 
     @property
-    def bounding_box(self) -> List[List[float]]:
+    def bounding_box(self) -> list[list[float]]:
         x, y, z = zip(*chain.from_iterable(self.positionPairs))
         return [[min(x), min(y), min(z)], [min(x), min(y), min(z)]]
 
 
 @dataclass
 class Cubes(Primitive):
-    """
-    Create a set of cubes. All cubes will have the same color and width.
+    """Create a set of cubes. All cubes will have the same color and width.
+
     :param positions: This is a list of lists corresponding to the vector
     positions of the cubes.
     :param color: Cube color as a hexadecimal string, e.g. #ff0000
@@ -367,14 +352,14 @@ class Cubes(Primitive):
     and trigger and event
     """
 
-    positions: List[List[float]]
-    _animate: Optional[List[List[float]]] = None
-    color: Optional[str] = None
-    width: Optional[float] = None
+    positions: list[list[float]]
+    _animate: list[list[float]] | None = None
+    color: str | None = None
+    width: float | None = None
     type: str = field(default="cubes", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
@@ -386,9 +371,6 @@ class Cubes(Primitive):
         new_positions = list(
             chain.from_iterable([cube.positions for cube in cube_list])
         )
-        new__animate = list(
-            chain.from_iterable([cube._animate for cube in cube_list if cube._animate])
-        )
         return cls(
             positions=new_positions,
             color=cube_list[0].color,
@@ -399,9 +381,8 @@ class Cubes(Primitive):
 
 @dataclass
 class Lines(Primitive):
-    """
-    Create a set of lines. All lines will have the same color, thickness and
-    (optional) dashes.
+    """Create a set of lines. All lines will have the same color, thickness and (optional) dashes.
+
     :param positions: This is a list of lists corresponding to the positions of
     the lines. Each consecutive pair of vectors corresponds to the start and end
     position of a line segment (line segments do not have to be joined
@@ -417,17 +398,17 @@ class Lines(Primitive):
     and trigger and event
     """
 
-    positions: List[List[float]]
-    _animate: Optional[List[List[float]]] = None
-    color: str = None
-    linewidth: float = None
-    scale: float = None
-    dashSize: float = None
-    gapSize: float = None
+    positions: list[list[float]]
+    _animate: list[list[float]] | None = None
+    color: str | None = None
+    linewidth: float | None = None
+    scale: float | None = None
+    dashSize: float | None = None
+    gapSize: float | None = None
     type: str = field(default="lines", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
@@ -439,9 +420,6 @@ class Lines(Primitive):
         new_positions = list(
             chain.from_iterable([line.positions for line in line_list])
         )
-        new__animate = list(
-            chain.from_iterable([line._animate for line in line_list if line._animate])
-        )
         return cls(
             positions=new_positions,
             color=line_list[0].color,
@@ -455,61 +433,59 @@ class Lines(Primitive):
 
 @dataclass
 class Surface:
-    """
-    Define a surface by its vertices. Please also provide normals if known.
-    Opacity can be set to enable transparency, but note that the current
-    Three.js renderer doesn't support nested transparent objects very well.
+    """Define a surface by its vertices.
+
+    Please also provide normals if known. Opacity can be set to enable transparency, but note that
+    the current Three.js renderer doesn't support nested transparent objects very well.
     """
 
-    positions: List[List[float]]
-    _animate: Optional[List[List[float]]] = None
-    normals: Optional[List[List[float]]] = None
-    color: str = None
-    opacity: float = None
+    positions: list[list[float]]
+    _animate: list[list[float]] | None = None
+    normals: list[list[float]] | None = None
+    color: str | None = None
+    opacity: float | None = None
     show_edges: bool = False
     type: str = field(default="surface", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
-    def bounding_box(self) -> List[List[float]]:
+    def bounding_box(self) -> list[list[float]]:
         # Not used in the calculation of the bounding box
         return [[0, 0, 0], [0, 0, 0]]
 
 
 @dataclass
 class Convex:
-    """
-    Create a surface from the convex hull formed by list of points. Note that
-    at least four points must be specified. The current Three.js renderer uses
-    the QuickHull algorithm. Opacity can be set to enable transparency, but note
-    that the current Three.js renderer doesn't support nested transparent
-    objects very well.
+    """Create a surface from the convex hull formed by list of points.
+
+    Note that at least four points must be specified. The current Three.js renderer uses the
+    QuickHull algorithm. Opacity can be set to enable transparency, but note that the current
+    Three.js renderer doesn't support nested transparent objects very well.
     """
 
-    positions: List[List[float]]
-    _animate: Optional[List[List[float]]] = None
-    color: str = None
-    opacity: float = None
+    positions: list[list[float]]
+    _animate: list[list[float]] | None = None
+    color: str | None = None
+    opacity: float | None = None
     type: str = field(default="convex", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
-    def bounding_box(self) -> List[List[float]]:
+    def bounding_box(self) -> list[list[float]]:
         # Not used in the calculation of the bounding box
         return [[0, 0, 0], [0, 0, 0]]
 
 
 @dataclass
 class Arrows(Primitive):
-    """
-    Create a set of arrows. All arrows will have the same color radius and
-    head shape.
+    """Create a set of arrows. All arrows will have the same color radius and head shape.
+
     :param positionPairs: This is a list of pairs of lists corresponding to the
     start and end position of the cylinder.
     :param color: Cylinder color as a hexadecimal string, e.g. #ff0000
@@ -520,16 +496,16 @@ class Arrows(Primitive):
     and trigger and event
     """
 
-    positionPairs: List[List[List[float]]]
-    _animate: Optional[List[List[List[float]]]] = None
-    color: Optional[str] = None
-    radius: Optional[float] = None
-    headLength: Optional[float] = None
-    headWidth: Optional[float] = None
+    positionPairs: list[list[list[float]]]
+    _animate: list[list[list[float]]] | None = None
+    color: str | None = None
+    radius: float | None = None
+    headLength: float | None = None
+    headWidth: float | None = None
     type: str = field(default="arrows", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
     @property
@@ -541,11 +517,6 @@ class Arrows(Primitive):
         new_positionPairs = list(
             chain.from_iterable([arrow.positionPairs for arrow in arrow_list])
         )
-        new__animate = list(
-            chain.from_iterable(
-                [arrow._animate for arrow in arrow_list if arrow._animate]
-            )
-        )
         return cls(
             positionPairs=new_positionPairs,
             color=arrow_list[0].color,
@@ -556,38 +527,34 @@ class Arrows(Primitive):
         )
 
     @property
-    def bounding_box(self) -> List[List[float]]:
+    def bounding_box(self) -> list[list[float]]:
         x, y, z = zip(*chain.from_iterable(self.positionPairs))
         return [[min(x), min(y), min(z)], [min(x), min(y), min(z)]]
 
 
 @dataclass
 class Label:
-    """
-    Add a label to an object.
-    """
+    """Add a label to an object."""
 
     label: str
-    labelHover: str = None
-    position: List[List[float]] = None
+    labelHover: str | None = None
+    position: list[list[float]] | None = None
     type: str = field(default="labels", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
 
 
 @dataclass
 class Bezier:
-    """
-    A tube shaped by Bézier control points.
-    """
+    """A tube shaped by Bézier control points."""
 
-    controlPoints: List[List[List[float]]] = None
-    color: List[str] = None
-    radius: List[float] = None
+    controlPoints: list[list[list[float]]] | None = None
+    color: list[str] | None = None
+    radius: list[float] | None = None
     type: str = field(default="bezier", init=False)  # private field
-    visible: bool = None
+    visible: bool | None = None
     clickable: bool = False
-    reference: Optional[str] = None
+    reference: str | None = None
     _meta: Any = None
