@@ -1,11 +1,12 @@
-import os
-import warnings
-from typing import Any, Dict, List, Optional, Union
+from __future__ import annotations
 
-from dash import dcc
-from dash import html
-from habanero import content_negotiation
-from monty.serialization import dumpfn, loadfn
+import warnings
+from typing import Any
+from uuid import uuid4
+
+import dash_mp_components as mpc
+from dash import dcc, html
+from monty.serialization import loadfn
 
 from crystal_toolkit import MODULE_PATH
 from crystal_toolkit.settings import SETTINGS
@@ -28,9 +29,8 @@ Helper methods to make working with Bulma classes easier.
 
 
 def _update_css_class(kwargs, class_name):
-    """
-    Convenience function to update className while respecting
-    any additional classNames already set.
+    """Convenience function to update className while respecting any additional classNames already
+    set.
     """
     if "className" in kwargs:
         kwargs["className"] += f" {class_name}"
@@ -50,6 +50,12 @@ class Container(html.Div):
         super().__init__(*args, **kwargs)
 
 
+class Block(html.Div):
+    def __init__(self, *args, **kwargs):
+        _update_css_class(kwargs, "block")
+        super().__init__(*args, **kwargs)
+
+
 class Columns(html.Div):
     def __init__(
         self,
@@ -121,9 +127,9 @@ class MessageBody(html.Div):
 
 class Icon(html.Span):
     def __init__(self, kind="download", fill="s", *args, **kwargs):
-        """
-        Font-awesome icon. Good options for kind are "info-circle",
-        "question-circle", "book", "code".
+        """Font-awesome icon.
+
+        Good options for kind are "info-circle", "question-circle", "book", "code".
         """
         _update_css_class(kwargs, "icon")
         if "fontastic" not in kind:
@@ -230,7 +236,7 @@ class Tag(html.Div):
 
 
 class TagContainer(html.Div):
-    def __init__(self, tags: List[Tag], *args, **kwargs):
+    def __init__(self, tags: list[Tag], *args, **kwargs):
         _update_css_class(kwargs, "field is-grouped is-grouped-multiline")
         tags = [html.Div(tag, className="control") for tag in tags]
         super().__init__(tags, *args, **kwargs)
@@ -307,10 +313,7 @@ class Field(html.Div):
 
 
 class Control(html.Div):
-    """
-    Control tag to wrap form elements,
-    see https://bulma.io/documentation/form/general/
-    """
+    """Control tag to wrap form elements, see https://bulma.io/documentation/form/general/"""
 
     def __init__(self, *args, **kwargs):
         _update_css_class(kwargs, "control")
@@ -318,30 +321,44 @@ class Control(html.Div):
 
 
 def get_tooltip(
-    tooltip: html.Div, tooltip_text: str, underline: bool = True
-) -> html.Div:
-    """
-    Add a tooltip, typically for help text.
-    :param tooltip: element to apply tooltip to
-    :param tooltip_text: text to show on hover
-    :param underline: whether to show hint that element provides tooltip functionality
-    :return: html.Div
-    """
-    if underline:
-        style = None
-    else:
-        style = {"borderBottom": "0px"}
+    tooltip_label: Any,
+    tooltip_text: str,
+    underline: bool = True,
+    tooltip_id: str = "",
+    wrapper_class: str = None,
+    **kwargs,
+):
+    """Uses the tooltip component from dash-mp-components to add a tooltip, typically for help text.
+    This component uses react-tooltip under the hood.
 
-    return html.Div(
-        [tooltip, html.Span(tooltip_text, className="tooltiptext")],
-        className="tooltip",
-        style=style,
+    :param tooltip_label: text or component to display and apply hover behavior to
+    :param tooltip_text: text to show on hover
+    :param tooltip_id: unique id of the tooltip (will generate one if not supplied)
+    :param wrapper_class: class to add to the span that wraps all the returned tooltip components (label + content)
+    :param kwargs: additional props added to Tooltip component. See the components js file in
+        dash-mp-components for a full list of props.
+    :return: html.Span
+    """
+    if not tooltip_id:
+        tooltip_id = uuid4().hex
+
+    tooltip_class = "tooltip-label" if underline else None
+    return html.Span(
+        [
+            html.Span(
+                tooltip_label,
+                className=tooltip_class,
+                **{"data-tip": True, "data-for": tooltip_id},
+            ),
+            mpc.Tooltip(tooltip_text, id=tooltip_id, **kwargs),
+        ],
+        className=wrapper_class,
     )
 
 
-def get_data_list(data: Dict[str, str]):
-    """
-    Show a formatted table of data items.
+def get_data_list(data: dict[str, str]):
+    """Show a formatted table of data items.
+
     :param data: dictionary of label, value pairs
     :return: html.Div
     """
@@ -360,9 +377,9 @@ def get_data_list(data: Dict[str, str]):
     return html.Table([html.Tbody(contents)], className="table")
 
 
-def get_table(rows: List[List[Any]], header: Optional[List[str]] = None) -> html.Table:
-    """
-    Create a HTML table from a list of elements.
+def get_table(rows: list[list[Any]], header: list[str] | None = None) -> html.Table:
+    """Create a HTML table from a list of elements.
+
     :param rows: list of list of cell contents
     :return: html.Table
     """
@@ -382,77 +399,27 @@ DOI_CACHE = loadfn(MODULE_PATH / "apps/assets/doi_cache.json")
 def cite_me(
     doi: str = None, manual_ref: str = None, cite_text: str = "Cite me"
 ) -> html.Div:
-    """
-    Create a button to show users how to cite a particular resource.
+    """Create a button to show users how to cite a particular resource.
+
     :param doi: DOI
     :param manual_ref: If DOI not available
     :param cite_text: Text to show as button label
     :return: A button
     """
     if doi:
-        if doi in DOI_CACHE:
-            ref = DOI_CACHE[doi]
-        else:
-            try:
-                ref = content_negotiation(ids=doi, format="text", style="ieee")[3:]
-                DOI_CACHE[doi] = ref
-                dumpfn(DOI_CACHE, MODULE_PATH / "apps/assets/doi_cache.json")
-            except Exception as exc:
-                print("Error retrieving DOI", doi, exc)
-                ref = f"DOI: {doi}"
-        tooltip_text = f"If this analysis is useful, please cite {ref}"
+        component = mpc.PublicationButton(id=doi, doi=doi, showTooltip=True)
     elif manual_ref:
         warnings.warn("Please use the DOI if available.")
-        tooltip_text = (
-            f"If this analysis is useful, please cite the "
-            f"relevant publication: {manual_ref}"
-        )
-    else:
-        tooltip_text = (
-            f"If this analysis is useful, please cite the "
-            f"relevant publication (publication pending)."
+        component = mpc.PublicationButton(
+            children=cite_text, id=manual_ref, url=manual_ref
         )
 
-    reference_button = html.A(
-        [
-            Button(
-                [Icon(kind="book"), html.Span(cite_text)],
-                size="small",
-                kind="link",
-                style={"height": "1.5rem"},
-            )
-        ],
-        href=f"https://dx.doi.org/{doi}",
-        target="_blank",
-    )
-
-    with_tooltip = get_tooltip(reference_button, tooltip_text, underline=False)
-
-    return with_tooltip
+    return component
 
 
-def add_label_help(input, label, help):
-
-    if (not label) and (not help):
-        return input
-
-    contents = []
-    if label and not help:
-        contents.append(html.Label(label, className="mpc-label"))
-    if label and help:
-        contents.append(
-            get_tooltip(html.Label(label, className="mpc-label"), dcc.Markdown(help))
-        )
-    contents.append(input)
-
-    return html.Div(
-        contents,
-        style={
-            "display": "inline-block",
-            "padding-right": "1rem",
-            "vertical-align": "top",
-        },
-    )
+def add_label_help(input, label, help) -> mpc.FilterField:
+    """Combine an input, label, and tooltip text into a single consistent component."""
+    return mpc.FilterField(input, id=uuid4().hex, label=label, tooltip=help)
 
 
 class Loading(dcc.Loading):
@@ -464,7 +431,6 @@ class Loading(dcc.Loading):
 
 
 def get_breadcrumb(parts):
-
     if not parts:
         return html.Div()
 
