@@ -1,42 +1,49 @@
+from __future__ import annotations
+
+from typing import Any, Sequence
+
 import numpy as np
-
-from crystal_toolkit.core.scene import Scene, Lines, Arrows, Spheres
-
 from pymatgen.core.lattice import Lattice
 
+from crystal_toolkit.core.scene import Arrows, Lines, Scene, Spheres
 
-def _axes_from_lattice(self, origin=None, scale=1, offset=0, **kwargs):
+
+def _axes_from_lattice(
+    self,
+    origin: Sequence[float] = (0, 0, 0),
+    scale: float = 1,
+    offset: float = 0,
+    **kwargs: Any,
+) -> Scene:
+    """_summary_
+
+    Args:
+        origin (list[float], optional): the reference position to place the compass. Defaults to None.
+        scale (float, optional): scale all the geometric objects that makes up the compass
+    the lattice vectors are normalized before the scaling so everything should. Defaults to 1.
+        offset (float, optional): shift the compass from the origin by a ratio of the diagonal
+    of the cell relative the size. Defaults to 0.
+
+    Returns:
+        Scene: crystal_toolkit.core.scene object
     """
-    Get the display components of the compass
-    :param lattice: the pymatgen Lattice object that contains the primitive
-    lattice vectors
-    :param origin: the reference position to place the compass
-    :param scale: scale all the geometric objects that makes up the compass
-    the lattice vectors are normalized before the scaling so everything should
-    be the same size
-    :param offset: shift the compass from the origin by a ratio of the diagonal
-    of the cell relative the size
-    :param **kwargs: keyword args to pass to the Arrows initializer
-    :return: Scene object
-    """
-
-    origin = origin or list([0, 0, 0])
-
-    o = np.array(origin)
+    np_origin = np.array(origin)
     # o = -self.get_cartesian_coords([0.5, 0.5, 0.5])
     # o = o - offset * (self.matrix[0] + self.matrix[1] + self.matrix[2])
     a = self.matrix[0] / np.linalg.norm(self.matrix[0]) * scale
     b = self.matrix[1] / np.linalg.norm(self.matrix[1]) * scale
     c = self.matrix[2] / np.linalg.norm(self.matrix[2]) * scale
-    a_arrow = [[o, o + a]]
-    b_arrow = [[o, o + b]]
-    c_arrow = [[o, o + c]]
+    a_arrow = [[np_origin, np_origin + a]]
+    b_arrow = [[np_origin, np_origin + b]]
+    c_arrow = [[np_origin, np_origin + c]]
 
     radius_scale = 0.07
     head_scale = 0.24
     head_width = 0.14
 
-    o_sphere = Spheres(positions=[o], color="white", radius=2 * radius_scale * scale)
+    o_sphere = Spheres(
+        positions=[np_origin], color="white", radius=2 * radius_scale * scale
+    )
 
     return Scene(
         name="axes",
@@ -72,7 +79,6 @@ def _axes_from_lattice(self, origin=None, scale=1, offset=0, **kwargs):
 
 
 def get_lattice_scene(self, origin=None, show_axes=False, **kwargs):
-
     o = -np.array((0, 0, 0))
     a, b, c = self.matrix[0], self.matrix[1], self.matrix[2]
     line_pairs = [
