@@ -1,5 +1,6 @@
+from __future__ import annotations
+
 from collections import defaultdict
-from typing import Optional
 
 from pymatgen.core.structure import Molecule
 
@@ -7,7 +8,7 @@ from crystal_toolkit.core.legend import Legend
 from crystal_toolkit.core.scene import Scene
 
 
-def get_scene_from_molecule(self, origin=None, legend: Optional[Legend] = None):
+def get_scene_from_molecule(self, origin=None, legend: Legend | None = None):
     """
     Create CTK objects for the lattice and sties
     Args:
@@ -25,8 +26,8 @@ def get_scene_from_molecule(self, origin=None, legend: Optional[Legend] = None):
 
     primitives = defaultdict(list)
 
-    for idx, site in enumerate(self):
-        site_scene = site.get_scene(origin=origin, legend=legend,)
+    for site in self:
+        site_scene = site.get_scene(origin=origin, legend=legend)
 
         for scene in site_scene.contents:
             primitives[scene.name] += scene.contents
