@@ -1,12 +1,11 @@
+from __future__ import annotations
+
 from collections import defaultdict
-from itertools import combinations
 
-import numpy as np
 from pymatgen.analysis.graphs import MoleculeGraph
 
-from crystal_toolkit.core.scene import Scene
 from crystal_toolkit.core.legend import Legend
-
+from crystal_toolkit.core.scene import Scene
 
 # TODO: fix Sam's bug (reorder)
 
@@ -21,7 +20,7 @@ def get_molecule_graph_scene(
 
     legend = legend or Legend(self.molecule)
 
-    primitives = defaultdict(list)
+    primitives: dict[str, list] = defaultdict(list)
 
     for idx, site in enumerate(self.molecule):
 
