@@ -1,25 +1,21 @@
+from __future__ import annotations
+
 from collections import defaultdict
 from itertools import combinations
 
 import numpy as np
-from pymatgen.core.sites import PeriodicSite
-from pymatgen.analysis.graphs import StructureGraph
-from pymatgen.symmetry.analyzer import SpacegroupAnalyzer, SymmetrizedStructure
-
-from crystal_toolkit.core.scene import Scene
-from crystal_toolkit.core.legend import Legend
-
 from matplotlib.cm import get_cmap
+from pymatgen.analysis.graphs import StructureGraph
+from pymatgen.core.sites import PeriodicSite
 
-from typing import Optional, List
+from crystal_toolkit.core.legend import Legend
+from crystal_toolkit.core.scene import Scene
 
 
 def _get_sites_to_draw(
     self, draw_image_atoms=True, bonded_sites_outside_unit_cell=False
 ):
-    """
-    Returns a list of site indices and image vectors.
-    """
+    """Returns a list of site indices and image vectors."""
 
     sites_to_draw = [(idx, (0, 0, 0)) for idx in range(len(self.structure))]
 
@@ -35,8 +31,8 @@ def _get_sites_to_draw(
 
             coord_permutations = [
                 x
-                for l in range(1, len(zero_elements) + 1)
-                for x in combinations(zero_elements, l)
+                for length in range(1, len(zero_elements) + 1)
+                for x in combinations(zero_elements, length)
             ]
 
             for perm in coord_permutations:
@@ -52,8 +48,8 @@ def _get_sites_to_draw(
 
             coord_permutations = [
                 x
-                for l in range(1, len(one_elements) + 1)
-                for x in combinations(one_elements, l)
+                for length in range(1, len(one_elements) + 1)
+                for x in combinations(one_elements, length)
             ]
 
             for perm in coord_permutations:
@@ -90,8 +86,8 @@ def get_structure_graph_scene(
     color_edges_by_edge_weight=False,
     edge_weight_color_scale="coolwarm",
     explicitly_calculate_polyhedra_hull=False,
-    legend: Optional[Legend] = None,
-    group_by_site_property: Optional[str] = None,
+    legend: Legend | None = None,
+    group_by_site_property: str | None = None,
     bond_radius: float = 0.1,
 ) -> Scene:
 
@@ -201,7 +197,7 @@ def get_structure_graph_scene(
                 primitives[scene.name] += scene.contents
 
     if group_by_site_property:
-        atoms_scenes: List[Scene] = []
+        atoms_scenes: list[Scene] = []
         for k, v in grouped_atom_scene_contents.items():
             atoms_scenes.append(Scene(name=k, contents=v))
         primitives["atoms"] = atoms_scenes
